@@ -21,7 +21,6 @@ import copy
 
 import eventlet
 from oslo.config import cfg
-import six.moves.urllib.parse as urlparse
 from webob.exc import HTTPBadRequest
 from webob.exc import HTTPConflict
 from webob.exc import HTTPForbidden
@@ -45,10 +44,10 @@ from glance.openstack.common import strutils
 import glance.registry.client.v1.api as registry
 from glance.store import get_from_backend
 from glance.store import get_known_schemes
-from glance.store import get_known_stores
 from glance.store import get_size_from_backend
 from glance.store import get_store_from_location
 from glance.store import get_store_from_scheme
+from glance.store import validate_external_location
 
 LOG = logging.getLogger(__name__)
 SUPPORTED_PARAMS = glance.api.v1.SUPPORTED_PARAMS
@@ -405,23 +404,19 @@ class Controller(controller.BaseController):
     @staticmethod
     def _validate_source(source, req):
         """
-        External sources (as specified via the location or copy-from headers)
-        are supported only over non-local store types, i.e. S3, Swift, HTTP.
-        Note the absence of file:// for security reasons, see LP bug #942118.
-        If the above constraint is violated, we reject with 400 "Bad Request".
+        To validate if external sources (as specified via the location
+        or copy-from headers) are supported. Otherwise we reject
+        with 400 "Bad Request".
         """
         if source:
-            pieces = urlparse.urlparse(source)
-            schemes = [scheme for scheme in get_known_schemes()
-                       if scheme != 'file']
-            for scheme in schemes:
-                if pieces.scheme == scheme:
-                    return source
-            msg = _("External sourcing not supported for store %s") % source
-            LOG.debug(msg)
-            raise HTTPBadRequest(explanation=msg,
-                                 request=req,
-                                 content_type="text/plain")
+            if validate_external_location(source):
+                return source
+            else:
+                msg = _("External source are not supported: '%s'") % source
+                LOG.debug(msg)
+                raise HTTPBadRequest(explanation=msg,
+                                     request=req,
+                                     content_type="text/plain")
 
     @staticmethod
     def _copy_from(req):
@@ -489,7 +484,7 @@ class Controller(controller.BaseController):
         """
         location = self._external_source(image_meta, req)
         store = image_meta.get('store')
-        if store and store not in get_known_stores():
+        if store and store not in get_known_schemes():
             msg = _("Required store %s is invalid") % store
             LOG.debug(msg)
             raise HTTPBadRequest(explanation=msg,
@@ -565,7 +560,7 @@ class Controller(controller.BaseController):
                 image_data, image_size = self._get_from_store(req.context,
                                                               copy_from)
             except Exception as e:
-                upload_utils.safe_kill(req, image_meta['id'])
+                upload_utils.safe_kill(req, image_meta['id'], 'queued')
                 msg = _("Copy from external source failed: %s") % e
                 LOG.debug(msg)
                 return
@@ -574,7 +569,7 @@ class Controller(controller.BaseController):
             try:
                 req.get_content_type(('application/octet-stream',))
             except exception.InvalidContentType:
-                upload_utils.safe_kill(req, image_meta['id'])
+                upload_utils.safe_kill(req, image_meta['id'], 'queued')
                 msg = _("Content-Type must be application/octet-stream")
                 LOG.debug(msg)
                 raise HTTPBadRequest(explanation=msg)
