@@ -1,6 +1,5 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation.
+# Copyright 2013 NTT corp.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,24 +14,45 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo.config import cfg
+import six
 import webob.exc
 
+from glance.api import policy
 from glance.api.v1 import controller
 from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 import glance.openstack.common.log as logging
-from glance import registry
+import glance.registry.client.v1.api as registry
 
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
+CONF.import_opt('image_member_quota', 'glance.common.config')
 
 
 class Controller(controller.BaseController):
 
+    def __init__(self):
+        self.policy = policy.Enforcer()
+
     def _check_can_access_image_members(self, context):
         if context.owner is None and not context.is_admin:
             raise webob.exc.HTTPUnauthorized(_("No authenticated user"))
 
+    def _enforce(self, req, action):
+        """Authorize an action against our policies"""
+        try:
+            self.policy.enforce(req.context, action, {})
+        except exception.Forbidden:
+            raise webob.exc.HTTPForbidden()
+
+    def _raise_404_if_image_deleted(self, req, image_id):
+        image = self.get_image_meta_or_404(req, image_id)
+        if image['status'] == 'deleted':
+            msg = _("Image with identifier %s has been deleted.") % image_id
+            raise webob.exc.HTTPNotFound(msg)
+
     def index(self, req, image_id):
         """
         Return a list of dictionaries indicating the members of the
@@ -47,6 +67,9 @@ class Controller(controller.BaseController):
                  'can_share': <SHARE_PERMISSION>, ...}, ...
             ]}
         """
+        self._enforce(req, 'get_members')
+        self._raise_404_if_image_deleted(req, image_id)
+
         try:
             members = registry.get_image_members(req.context, image_id)
         except exception.NotFound:
@@ -65,18 +88,18 @@ class Controller(controller.BaseController):
         Removes a membership from the image.
         """
         self._check_can_access_image_members(req.context)
+        self._enforce(req, 'delete_member')
+        self._raise_404_if_image_deleted(req, image_id)
 
         try:
             registry.delete_member(req.context, image_id, id)
             self._update_store_acls(req, image_id)
-        except exception.NotFound, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
-        except exception.Forbidden, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
+        except exception.NotFound as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except exception.Forbidden as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
 
@@ -84,6 +107,20 @@ class Controller(controller.BaseController):
         """This will cover the missing 'show' and 'create' actions"""
         raise webob.exc.HTTPMethodNotAllowed()
 
+    def _enforce_image_member_quota(self, req, attempted):
+        if CONF.image_member_quota < 0:
+            # If value is negative, allow unlimited number of members
+            return
+
+        maximum = CONF.image_member_quota
+        if attempted > maximum:
+            msg = _("The limit has been exceeded on the number of allowed "
+                    "image members for this image. Attempted: %(attempted)s, "
+                    "Maximum: %(maximum)s") % {'attempted': attempted,
+                                               'maximum': maximum}
+            raise webob.exc.HTTPRequestEntityTooLarge(explanation=msg,
+                                                      request=req)
+
     @utils.mutating
     def update(self, req, image_id, id, body=None):
         """
@@ -99,6 +136,12 @@ class Controller(controller.BaseController):
         remain unchanged and new memberships default to False.
         """
         self._check_can_access_image_members(req.context)
+        self._enforce(req, 'modify_member')
+        self._raise_404_if_image_deleted(req, image_id)
+
+        new_number_of_members = len(registry.get_image_members(req.context,
+                                                               image_id)) + 1
+        self._enforce_image_member_quota(req, new_number_of_members)
 
         # Figure out can_share
         can_share = None
@@ -107,18 +150,15 @@ class Controller(controller.BaseController):
         try:
             registry.add_member(req.context, image_id, id, can_share)
             self._update_store_acls(req, image_id)
-        except exception.Invalid, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPBadRequest(explanation=msg)
-        except exception.NotFound, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
-        except exception.Forbidden, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
+        except exception.Invalid as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=e.msg)
+        except exception.NotFound as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except exception.Forbidden as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
 
@@ -134,22 +174,26 @@ class Controller(controller.BaseController):
             ]}
         """
         self._check_can_access_image_members(req.context)
+        self._enforce(req, 'modify_member')
+        self._raise_404_if_image_deleted(req, image_id)
+
+        memberships = body.get('memberships')
+        if memberships:
+            new_number_of_members = len(body['memberships'])
+            self._enforce_image_member_quota(req, new_number_of_members)
 
         try:
             registry.replace_members(req.context, image_id, body)
             self._update_store_acls(req, image_id)
-        except exception.Invalid, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPBadRequest(explanation=msg)
-        except exception.NotFound, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
-        except exception.Forbidden, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
+        except exception.Invalid as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=e.msg)
+        except exception.NotFound as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except exception.Forbidden as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
 
         return webob.exc.HTTPNoContent()
 
@@ -168,14 +212,12 @@ class Controller(controller.BaseController):
         """
         try:
             members = registry.get_member_images(req.context, id)
-        except exception.NotFound, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPNotFound(msg)
-        except exception.Forbidden, e:
-            msg = "%s" % e
-            LOG.debug(msg)
-            raise webob.exc.HTTPForbidden(msg)
+        except exception.NotFound as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.msg)
+        except exception.Forbidden as e:
+            LOG.debug(six.text_type(e))
+            raise webob.exc.HTTPForbidden(explanation=e.msg)
         return dict(shared_images=members)
 
     def _update_store_acls(self, req, image_id):
