@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2013 OpenStack LLC.
+# Copyright 2013 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,4 +14,4 @@
 #    under the License.
 
 from glance.openstack.common import gettextutils
-gettextutils.install('glance')
+gettextutils.install('glance', lazy=True)
