@@ -15,47 +15,17 @@
 
 import copy
 
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 import stevedore
 
-from glance.i18n import _, _LE
+import glance.openstack.common.log as logging
 
 location_strategy_opts = [
-    cfg.StrOpt('location_strategy',
-               deprecated_for_removal=True,
-               deprecated_since="Caracal",
-               deprecated_reason=_("""
-In Bobcat, a new weighing mechanism has been introduced, which makes the
-location strategy obsolete.  This option is scheduled to be removed during the
-Dalmatian development cycle.
-"""),
-               default='location_order',
-               choices=('location_order', 'store_type'),
-               help=_("""
-Strategy to determine the preference order of image locations.
-
-This configuration option indicates the strategy to determine
-the order in which an image's locations must be accessed to
-serve the image's data. Glance then retrieves the image data
-from the first responsive active location it finds in this list.
-
-This option takes one of two possible values ``location_order``
-and ``store_type``. The default value is ``location_order``,
-which suggests that image data be served by using locations in
-the order they are stored in Glance. The ``store_type`` value
-sets the image location preference based on the order in which
-the storage backends are listed as a comma separated list for
-the configuration option ``store_type_preference``.
-
-Possible values:
-    * location_order
-    * store_type
-
-Related options:
-    * store_type_preference
-
-""")),
+    cfg.StrOpt('location_strategy', default='location_order',
+               help=_("This value sets what strategy will be used to "
+                      "determine the image location order. Currently "
+                      "two strategies are packaged with Glance "
+                      "'location_order' and 'store_type'."))
 ]
 
 CONF = cfg.CONF
@@ -82,23 +52,20 @@ def _load_strategies():
                 msg = (_('%(strategy)s is registered as a module twice. '
                          '%(module)s is not being used.') %
                        {'strategy': strategy_name, 'module': module_name})
-                LOG.warning(msg)
+                LOG.warn(msg)
             else:
                 # Initialize strategy module
                 mgr.driver.init()
                 modules[strategy_name] = mgr.driver
         except Exception as e:
-            LOG.error(_LE("Failed to load location strategy module "
-                          "%(module)s: %(e)s"), {'module': module_name,
-                                                 'e': e})
+            LOG.error(_("Failed to load location strategy module "
+                        "%(module)s: %(e)s") % {'module': module_name, 'e': e})
     return modules
 
 
 _available_strategies = _load_strategies()
 
 
-# TODO(kadachi): Not used but don't remove this until glance_store
-#                development/migration stage.
 def verify_location_strategy(conf=None, strategies=_available_strategies):
     """Validate user configured 'location_strategy' option value."""
     if not conf:
@@ -117,7 +84,7 @@ def get_ordered_locations(locations, **kwargs):
 
     :param locations: The original image location list.
     :param kwargs: Strategy-specific arguments for under layer strategy module.
-    :returns: The image location list with strategy-specific order.
+    :return: The image location list with strategy-specific order.
     """
     if not locations:
         return []
@@ -132,7 +99,7 @@ def choose_best_location(locations, **kwargs):
 
     :param locations: The original image location list.
     :param kwargs: Strategy-specific arguments for under layer strategy module.
-    :returns: The best location from image location list.
+    :return: The best location from image location list.
     """
     locations = get_ordered_locations(locations, **kwargs)
     if locations:
