@@ -15,50 +15,19 @@
 
 """Storage preference based location strategy module"""
 
-import urllib.parse as urlparse
-
-from oslo_config import cfg
-
-from glance.i18n import _
+from oslo.config import cfg
+import six
+import six.moves.urllib.parse as urlparse
 
 store_type_opts = [
-    cfg.ListOpt('store_type_preference',
+    cfg.ListOpt("store_type_preference",
                 default=[],
-                deprecated_for_removal=True,
-                deprecated_since="Caracal",
-                deprecated_reason=_("""
-In Bobcat, a new weighing mechanism has been introduced, which makes the
-location strategy obsolete.  This option is scheduled to be removed during the
-Dalmatian development cycle.
-"""),
-                help=_("""
-Preference order of storage backends.
-
-Provide a comma separated list of store names in the order in
-which images should be retrieved from storage backends.
-These store names must be registered with the ``stores``
-configuration option.
-
-NOTE: The ``store_type_preference`` configuration option is applied
-only if ``store_type`` is chosen as a value for the
-``location_strategy`` configuration option. An empty list will not
-change the location order.
-
-Possible values:
-    * Empty list
-    * Comma separated list of registered store names. Legal values are:
-        * file
-        * http
-        * rbd
-        * swift
-        * cinder
-        * vmware
-
-Related options:
-    * location_strategy
-    * stores
-
-"""))
+                help=_("The store names to use to get store preference order. "
+                       "The name must be registered by one of the stores "
+                       "defined by the 'known_stores' config option. "
+                       "This option will be applied when you using "
+                       "'store_type' option as image location strategy "
+                       "defined by the 'location_strategy' config option."))
 ]
 
 CONF = cfg.CONF
@@ -82,12 +51,15 @@ def init():
     # possible to prevent make relationships with Glance(server)-specific code,
     # for example: using functions within store module to validate
     # 'store_type_preference' option.
-    mapping = {'file': ['file', 'filesystem'],
+    mapping = {'filesystem': ['file', 'filesystem'],
                'http': ['http', 'https'],
                'rbd': ['rbd'],
+               's3': ['s3', 's3+http', 's3+https'],
                'swift': ['swift', 'swift+https', 'swift+http'],
+               'gridfs': ['gridfs'],
+               'sheepdog': ['sheepdog'],
                'cinder': ['cinder'],
-               'vmware': ['vsphere']}
+               'vmware_datastore': ['vsphere']}
     _STORE_TO_SCHEME_MAP.clear()
     _STORE_TO_SCHEME_MAP.update(mapping)
 
@@ -98,7 +70,7 @@ def get_ordered_locations(locations, uri_key='url', **kwargs):
 
     :param locations: The original image location list.
     :param uri_key: The key name for location URI in image location dictionary.
-    :returns: The image location list with preferred store type order.
+    :return: The image location list with preferred store type order.
     """
     def _foreach_store_type_preference():
         store_types = CONF.store_type_location_strategy.store_type_preference
@@ -123,7 +95,7 @@ def get_ordered_locations(locations, uri_key='url', **kwargs):
         pieces = urlparse.urlparse(uri.strip())
 
         store_name = None
-        for store, schemes in _STORE_TO_SCHEME_MAP.items():
+        for store, schemes in six.iteritems(_STORE_TO_SCHEME_MAP):
             if pieces.scheme.strip() in schemes:
                 store_name = store
                 break
