@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2010 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -254,11 +252,26 @@ def get_image_meta_from_headers(response):
                 raise exc.HTTPBadRequest(msg, content_type="text/plain")
             result[field_name] = value or None
     result['properties'] = properties
-    if 'size' in result:
-        try:
-            result['size'] = int(result['size'])
-        except ValueError:
-            raise exception.Invalid
+
+    for key in ('size', 'min_disk', 'min_ram'):
+        if key in result:
+            try:
+                result[key] = int(result[key])
+            except ValueError:
+                extra = (_("Cannot convert image %(key)s '%(value)s' "
+                           "to an integer.")
+                         % {'key': key, 'value': result[key]})
+                raise exception.InvalidParameterValue(value=result[key],
+                                                      param=key,
+                                                      extra_msg=extra)
+            if result[key] < 0:
+                extra = (_("Image %(key)s must be >= 0 "
+                           "('%(value)s' specified).")
+                         % {'key': key, 'value': result[key]})
+                raise exception.InvalidParameterValue(value=result[key],
+                                                      param=key,
+                                                      extra_msg=extra)
+
     for key in ('is_public', 'deleted', 'protected'):
         if key in result:
             result[key] = strutils.bool_from_string(result[key])
@@ -356,7 +369,7 @@ def get_terminal_size():
             height_width = struct.unpack('hh', fcntl.ioctl(sys.stderr.fileno(),
                                          termios.TIOCGWINSZ,
                                          struct.pack('HH', 0, 0)))
-        except:
+        except Exception:
             pass
 
         if not height_width:
@@ -368,18 +381,19 @@ def get_terminal_size():
                 result = p.communicate()
                 if p.returncode == 0:
                     return tuple(int(x) for x in result[0].split())
-            except:
+            except Exception:
                 pass
 
         return height_width
 
     def _get_terminal_size_win32():
         try:
-            from ctypes import windll, create_string_buffer
+            from ctypes import create_string_buffer
+            from ctypes import windll
             handle = windll.kernel32.GetStdHandle(-12)
             csbi = create_string_buffer(22)
             res = windll.kernel32.GetConsoleScreenBufferInfo(handle, csbi)
-        except:
+        except Exception:
             return None
         if res:
             import struct
@@ -440,7 +454,7 @@ def setup_remote_pydev_debug(host, port):
                         stdoutToServer=True,
                         stderrToServer=True)
         return True
-    except:
+    except Exception:
         LOG.exception(error_msg)
         raise
 
@@ -491,14 +505,20 @@ def validate_key_cert(key_file, cert_file):
         error_filename = cert_file
         cert_str = open(cert_file, "r").read()
         cert = crypto.load_certificate(crypto.FILETYPE_PEM, cert_str)
-    except IOError, ioe:
-        raise RuntimeError(_("There is a problem with your %s "
-                             "%s.  Please verify it.  Error: %s")
-                           % (error_key_name, error_filename, ioe))
-    except crypto.Error, ce:
-        raise RuntimeError(_("There is a problem with your %s "
-                             "%s.  Please verify it. OpenSSL error: %s")
-                           % (error_key_name, error_filename, ce))
+    except IOError as ioe:
+        raise RuntimeError(_("There is a problem with your %(error_key_name)s "
+                             "%(error_filename)s.  Please verify it."
+                             "  Error: %(ioe)s") %
+                           {'error_key_name': error_key_name,
+                            'error_filename': error_filename,
+                            'ioe': ioe})
+    except crypto.Error as ce:
+        raise RuntimeError(_("There is a problem with your %(error_key_name)s "
+                             "%(error_filename)s.  Please verify it. OpenSSL"
+                             " error: %(ce)s") %
+                           {'error_key_name': error_key_name,
+                            'error_filename': error_filename,
+                            'ce': ce})
 
     try:
         data = str(uuid.uuid4())
@@ -506,11 +526,13 @@ def validate_key_cert(key_file, cert_file):
 
         out = crypto.sign(key, data, digest)
         crypto.verify(cert, out, data, digest)
-    except crypto.Error, ce:
+    except crypto.Error as ce:
         raise RuntimeError(_("There is a problem with your key pair.  "
-                             "Please verify that cert %s and key %s "
-                             "belong together.  OpenSSL error %s")
-                           % (cert_file, key_file, ce))
+                             "Please verify that cert %(cert_file)s and "
+                             "key %(key_file)s belong together.  OpenSSL "
+                             "error %(ce)s") % {'cert_file': cert_file,
+                                                'key_file': key_file,
+                                                'ce': ce})
 
 
 def get_test_suite_socket():
@@ -524,3 +546,15 @@ def get_test_suite_socket():
         os.close(fd)
         return sock
     return None
+
+
+def is_uuid_like(val):
+    """Returns validation of a value as a UUID.
+
+    For our purposes, a UUID is a canonical form string:
+    aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa
+    """
+    try:
+        return str(uuid.UUID(val)) == val
+    except (TypeError, ValueError, AttributeError):
+        return False
