@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -28,12 +26,12 @@ LOG = logging.getLogger(__name__)
 
 
 String = lambda length: sqlalchemy.types.String(
-    length=length, convert_unicode=False, assert_unicode=None,
+    length=length, convert_unicode=False,
     unicode_error=None, _warn_on_bytestring=False)
 
 
 Text = lambda: sqlalchemy.types.Text(
-    length=None, convert_unicode=False, assert_unicode=None,
+    length=None, convert_unicode=False,
     unicode_error=None, _warn_on_bytestring=False)
 
 
@@ -49,6 +47,9 @@ Integer = lambda: sqlalchemy.types.Integer()
 BigInteger = lambda: sqlalchemy.types.BigInteger()
 
 
+PickleType = lambda: sqlalchemy.types.PickleType()
+
+
 def from_migration_import(module_name, fromlist):
     """
     Import a migration file and return the module
@@ -92,11 +93,11 @@ def from_migration_import(module_name, fromlist):
 
 def create_tables(tables):
     for table in tables:
-        LOG.info(_("creating table %(table)s") % locals())
+        LOG.info(_("creating table %(table)s") % {'table': table})
         table.create()
 
 
 def drop_tables(tables):
     for table in tables:
-        LOG.info(_("dropping table %(table)s") % locals())
+        LOG.info(_("dropping table %(table)s") % {'table': table})
         table.drop()
