@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,14 +18,23 @@ from sqlalchemy.schema import (
 
 from glance.db.sqlalchemy.migrate_repo.schema import (
     Boolean, DateTime, Integer, String, Text, create_tables, drop_tables,
-    from_migration_import)
+    from_migration_import)  # noqa
 
 
 def define_image_properties_table(meta):
     (define_images_table,) = from_migration_import(
         '001_add_images_table', ['define_images_table'])
 
-    images = define_images_table(meta)
+    images = define_images_table(meta)  # noqa
+
+    # NOTE(dperaza) DB2: specify the UniqueConstraint option when creating the
+    # table will cause an index being created to specify the index
+    # name and skip the step of creating another index with the same columns.
+    # The index name is needed so it can be dropped and re-created later on.
+
+    constr_kwargs = {}
+    if meta.bind.name == 'ibm_db_sa':
+        constr_kwargs['name'] = 'ix_image_properties_image_id_key'
 
     image_properties = Table('image_properties',
                              meta,
@@ -50,13 +57,15 @@ def define_image_properties_table(meta):
                                     nullable=False,
                                     default=False,
                                     index=True),
-                             UniqueConstraint('image_id', 'key'),
+                             UniqueConstraint('image_id', 'key',
+                                              **constr_kwargs),
                              mysql_engine='InnoDB',
                              extend_existing=True)
 
-    Index('ix_image_properties_image_id_key',
-          image_properties.c.image_id,
-          image_properties.c.key)
+    if meta.bind.name != 'ibm_db_sa':
+        Index('ix_image_properties_image_id_key',
+              image_properties.c.image_id,
+              image_properties.c.key)
 
     return image_properties
 
