@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,12 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from migrate.changeset import *
-from sqlalchemy import *
+from migrate.changeset import *  # noqa
+from sqlalchemy import *  # noqa
 
 from glance.db.sqlalchemy.migrate_repo.schema import (
     Boolean, DateTime, BigInteger, Integer, String,
-    Text, from_migration_import)
+    Text, from_migration_import)  # noqa
 
 
 def get_images_table(meta):
