@@ -1,7 +1,9 @@
---
--- This is necessary because SQLite does not support
--- RENAME INDEX or ALTER TABLE CHANGE COLUMN.
---
+/*
+ * This is necessary because SQLite does not support
+ * RENAME INDEX or ALTER TABLE CHANGE COLUMN.
+ */
+BEGIN TRANSACTION;
+
 CREATE TEMPORARY TABLE image_properties_backup (
 	id INTEGER NOT NULL,
 	image_id INTEGER NOT NULL,
@@ -42,3 +44,4 @@ SELECT id, image_id, name, value, created_at, updated_at, deleted_at, deleted
 FROM image_properties_backup;
 
 DROP TABLE image_properties_backup;
+COMMIT;
