@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -27,17 +25,18 @@ from glance.common import exception
 from glance.common import utils
 from glance.openstack.common import importutils
 import glance.openstack.common.log as logging
+from glance.openstack.common import units
 
 LOG = logging.getLogger(__name__)
 
 image_cache_opts = [
     cfg.StrOpt('image_cache_driver', default='sqlite',
                help=_('The driver to use for image cache management.')),
-    cfg.IntOpt('image_cache_max_size', default=10 * (1024 ** 3),  # 10 GB
+    cfg.IntOpt('image_cache_max_size', default=10 * units.Gi,  # 10 GB
                help=_('The maximum size in bytes that the cache can use.')),
     cfg.IntOpt('image_cache_stall_time', default=86400,  # 24 hours
                help=_('The amount of time to let an image remain in the '
-                      'cache without being accessed')),
+                      'cache without being accessed.')),
     cfg.StrOpt('image_cache_dir',
                help=_('Base directory that the Image Cache uses.')),
 ]
@@ -66,7 +65,9 @@ class ImageCache(object):
         except ImportError as import_err:
             LOG.warn(_("Image cache driver "
                        "'%(driver_name)s' failed to load. "
-                       "Got error: '%(import_err)s.") % locals())
+                       "Got error: '%(import_err)s."),
+                     {'driver_name': driver_name,
+                      'import_err': import_err})
 
             driver_module = __name__ + '.drivers.sqlite.Driver'
             LOG.info(_("Defaulting to SQLite driver."))
@@ -85,7 +86,9 @@ class ImageCache(object):
             driver_module = self.driver_class.__module__
             LOG.warn(_("Image cache driver "
                        "'%(driver_module)s' failed to configure. "
-                       "Got error: '%(config_err)s") % locals())
+                       "Got error: '%(config_err)s"),
+                     {'driver_module': driver_module,
+                      'config_err': config_err})
             LOG.info(_("Defaulting to SQLite driver."))
             default_module = __name__ + '.drivers.sqlite.Driver'
             self.driver_class = importutils.import_class(default_module)
@@ -173,8 +176,8 @@ class ImageCache(object):
 
         overage = current_size - max_size
         LOG.debug(_("Image cache currently %(overage)d bytes over max "
-                    "size. Starting prune to max size of %(max_size)d ") %
-                  locals())
+                    "size. Starting prune to max size of %(max_size)d "),
+                  {'overage': overage, 'max_size': max_size})
 
         total_bytes_pruned = 0
         total_files_pruned = 0
@@ -191,7 +194,9 @@ class ImageCache(object):
 
         LOG.debug(_("Pruning finished pruning. "
                     "Pruned %(total_files_pruned)d and "
-                    "%(total_bytes_pruned)d.") % locals())
+                    "%(total_bytes_pruned)d."),
+                  {'total_files_pruned': total_files_pruned,
+                   'total_bytes_pruned': total_bytes_pruned})
         return total_files_pruned, total_bytes_pruned
 
     def clean(self, stall_time=None):
@@ -246,7 +251,7 @@ class ImageCache(object):
                 if (image_checksum and
                         image_checksum != current_checksum.hexdigest()):
                     msg = _("Checksum verification failed. Aborted "
-                            "caching of image '%s'." % image_id)
+                            "caching of image '%s'.") % image_id
                     raise exception.GlanceException(msg)
 
         except exception.GlanceException as e:
@@ -256,8 +261,10 @@ class ImageCache(object):
             raise
         except Exception as e:
             LOG.exception(_("Exception encountered while tee'ing "
-                            "image '%s' into cache: %s. Continuing "
-                            "with response.") % (image_id, e))
+                            "image '%(image_id)s' into cache: %(error)s. "
+                            "Continuing with response.") %
+                          {'image_id': image_id,
+                           'error': e})
 
             # If no checksum provided continue responding even if
             # caching failed.
@@ -291,7 +298,7 @@ class ImageCache(object):
 
         :retval True if image file was cached, False otherwise
         """
-        CHUNKSIZE = 64 * 1024 * 1024
+        CHUNKSIZE = 64 * units.Mi
 
         return self.cache_image_iter(image_id,
                                      utils.chunkiter(image_file, CHUNKSIZE))
