@@ -440,9 +440,10 @@ class Controller(object):
 
         purge_props = req.headers.get("X-Glance-Registry-Purge-Props", "false")
         try:
-            LOG.debug(_("Updating image %(id)s with metadata: "
-                        "%(image_data)r"), {'id': id,
-                                            'image_data': image_data})
+            LOG.debug("Updating image %(id)s with metadata: %(image_data)r",
+                      {'id': id,
+                       'image_data': dict((k, v) for k, v in image_data.items()
+                                          if k != 'locations')})
             image_data = _normalize_image_location_for_db(image_data)
             if purge_props == "true":
                 purge_props = True
