@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2010-2011 OpenStack LLC.
+# Copyright 2010-2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -35,7 +33,28 @@ class Controller(object):
 
     def __init__(self):
         self.db_api = glance.db.get_api()
-        self.db_api.setup_db_env()
+
+    def is_image_sharable(self, context, image):
+        """Return True if the image can be shared to others in this context."""
+        # Is admin == image sharable
+        if context.is_admin:
+            return True
+
+        # Only allow sharing if we have an owner
+        if context.owner is None:
+            return False
+
+        # If we own the image, we can share it
+        if context.owner == image['owner']:
+            return True
+
+        members = self.db_api.image_member_find(context,
+                                                image_id=image['id'],
+                                                member=context.owner)
+        if members:
+            return members[0]['can_share']
+
+        return False
 
     def index(self, req, image_id):
         """
@@ -89,7 +108,7 @@ class Controller(object):
             raise webob.exc.HTTPNotFound()
 
         # Can they manipulate the membership?
-        if not self.db_api.is_image_sharable(req.context, image):
+        if not self.is_image_sharable(req.context, image):
             msg = _("User lacks permission to share image %(id)s")
             LOG.info(msg % {'id': image_id})
             msg = _("No permission to share that image")
@@ -202,7 +221,7 @@ class Controller(object):
             raise webob.exc.HTTPNotFound()
 
         # Can they manipulate the membership?
-        if not self.db_api.is_image_sharable(req.context, image):
+        if not self.is_image_sharable(req.context, image):
             msg = _("User lacks permission to share image %(id)s")
             LOG.info(msg % {'id': image_id})
             msg = _("No permission to share that image")
@@ -262,7 +281,7 @@ class Controller(object):
             raise webob.exc.HTTPNotFound()
 
         # Can they manipulate the membership?
-        if not self.db_api.is_image_sharable(req.context, image):
+        if not self.is_image_sharable(req.context, image):
             msg = _("User lacks permission to share image %(id)s")
             LOG.info(msg % {'id': image_id})
             msg = _("No permission to share that image")
@@ -275,8 +294,9 @@ class Controller(object):
         if members:
             self.db_api.image_member_delete(req.context, members[0]['id'])
         else:
-            msg = _("%(id)s is not a member of image %(image_id)s")
-            LOG.debug(msg % locals())
+            msg = (_("%(id)s is not a member of image %(image_id)s") %
+                   {'id': id, 'image_id': image_id})
+            LOG.debug(msg)
             msg = _("Membership could not be found.")
             raise webob.exc.HTTPNotFound(explanation=msg)
 
@@ -291,7 +311,7 @@ class Controller(object):
         """
         try:
             members = self.db_api.image_member_find(req.context, member=id)
-        except exception.NotFound as e:
+        except exception.NotFound:
             msg = _("Member %(id)s not found")
             LOG.info(msg % {'id': id})
             msg = _("Membership could not be found.")
