@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -49,7 +47,7 @@ registry_client_ctx_opts = [
     cfg.StrOpt('admin_password', secret=True,
                help=_('The administrators password.')),
     cfg.StrOpt('admin_tenant_name', secret=True,
-               help=_('The tenant name of the adminstrative user.')),
+               help=_('The tenant name of the administrative user.')),
     cfg.StrOpt('auth_url',
                help=_('The URL to the keystone service.')),
     cfg.StrOpt('auth_strategy', default='noauth',
