@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Red Hat, Inc
 # All Rights Reserved.
 #
@@ -19,12 +17,11 @@
 from __future__ import absolute_import
 
 from oslo.config import cfg
-import urlparse
+import six.moves.urllib.parse as urlparse
 
 from glance.common import exception
 from glance.openstack.common import excutils
 import glance.openstack.common.log as logging
-import glance.store
 import glance.store.base
 import glance.store.location
 
@@ -44,8 +41,8 @@ gridfs_opts = [
                     "or a mongodb URI, or a list of hostnames / mongodb URIs. "
                     "If host is an IPv6 literal it must be enclosed "
                     "in '[' and ']' characters following the RFC2732 "
-                    "URL syntax (e.g. '[::1]' for localhost)"),
-    cfg.StrOpt('mongodb_store_db', default=None, help='Database to use'),
+                    "URL syntax (e.g. '[::1]' for localhost)."),
+    cfg.StrOpt('mongodb_store_db', default=None, help='Database to use.'),
 ]
 
 CONF = cfg.CONF
@@ -97,7 +94,7 @@ class Store(glance.store.base.Store):
         itself, it should raise `exception.BadStoreConfiguration`
         """
         if pymongo is None:
-            msg = _("Missing dependecies: pymongo")
+            msg = _("Missing dependencies: pymongo")
             raise exception.BadStoreConfiguration(store_name="gridfs",
                                                   reason=msg)
 
@@ -113,8 +110,8 @@ class Store(glance.store.base.Store):
     def _option_get(self, param):
         result = getattr(CONF, param)
         if not result:
-            reason = _("Could not find %(param)s in configuration "
-                       "options.") % locals()
+            reason = (_("Could not find %(param)s in configuration "
+                        "options.") % {'param': param})
             LOG.debug(reason)
             raise exception.BadStoreConfiguration(store_name="gridfs",
                                                   reason=reason)
@@ -183,20 +180,23 @@ class Store(glance.store.base.Store):
             raise exception.Duplicate(_("GridFS already has an image at "
                                         "location %s") % loc.get_uri())
 
-        LOG.debug(_("Adding a new image to GridFS with id %s and size %s") %
-                 (image_id, image_size))
+        LOG.debug(_("Adding a new image to GridFS with id %(id)s and "
+                    "size %(size)s") % {'id': image_id,
+                                        'size': image_size})
 
         try:
             self.fs.put(image_file, _id=image_id)
             image = self._get_file(loc)
-        except:
+        except Exception:
             # Note(zhiyan): clean up already received data when
             # error occurs such as ImageSizeLimitExceeded exception.
             with excutils.save_and_reraise_exception():
                 self.fs.delete(image_id)
 
-        LOG.debug(_("Uploaded image %s, md5 %s, length %s to GridFS") %
-                 (image._id, image.md5, image.length))
+        LOG.debug(_("Uploaded image %(id)s, md5 %(md5)s, length %(length)s "
+                    "to GridFS") % {'id': image._id,
+                                    'md5': image.md5,
+                                    'length': image.length})
 
         return (loc.get_uri(), image.length, image.md5, {})
 
