@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2010 OpenStack, LLC
+# Copyright 2010 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,9 +19,9 @@ import hashlib
 import httplib
 import re
 import tempfile
-import urlparse
 
 from oslo.config import cfg
+import six.moves.urllib.parse as urlparse
 
 from glance.common import exception
 from glance.common import utils
@@ -45,7 +43,7 @@ s3_opts = [
                help=_('The S3 bucket to be used to store the Glance data.')),
     cfg.StrOpt('s3_store_object_buffer_dir',
                help=_('The local directory where uploads will be staged '
-                      'before they are transfered into S3.')),
+                      'before they are transferred into S3.')),
     cfg.BoolOpt('s3_store_create_bucket_on_put', default=False,
                 help=_('A boolean to determine if the S3 bucket should be '
                        'created on upload if it does not exist or if '
@@ -122,7 +120,7 @@ class StoreLocation(glance.store.location.StoreLocation):
                        "s3+https:// scheme, like so: "
                        "s3+https://accesskey:secretkey@"
                        "s3.amazonaws.com/bucket/key-id")
-            LOG.debug(_("Invalid store uri %(uri)s: %(reason)s") % locals())
+            LOG.debug(_("Invalid store uri: %s") % reason)
             raise exception.BadStoreUri(message=reason)
 
         pieces = urlparse.urlparse(uri)
@@ -158,7 +156,7 @@ class StoreLocation(glance.store.location.StoreLocation):
             path_parts = path.split('/')
             self.key = path_parts.pop()
             self.bucket = path_parts.pop()
-            if len(path_parts) > 0:
+            if path_parts:
                 self.s3serviceurl = '/'.join(path_parts).strip('/')
             else:
                 reason = _("Badly formed S3 URI. Missing s3 service URL.")
@@ -184,17 +182,18 @@ class ChunkedFile(object):
     def __iter__(self):
         """Return an iterator over the image file"""
         try:
-            while True:
-                chunk = self.fp.read(ChunkedFile.CHUNKSIZE)
-                if chunk:
-                    yield chunk
-                else:
-                    break
+            if self.fp:
+                while True:
+                    chunk = self.fp.read(ChunkedFile.CHUNKSIZE)
+                    if chunk:
+                        yield chunk
+                    else:
+                        break
         finally:
             self.close()
 
     def getvalue(self):
-        """Return entire string value... used in testing"""
+        """Return entire string value... used in testing."""
         data = ""
         self.len = 0
         for chunk in self:
@@ -204,7 +203,7 @@ class ChunkedFile(object):
         return data
 
     def close(self):
-        """Close the internal file pointer"""
+        """Close the internal file pointer."""
         if self.fp:
             self.fp.close()
             self.fp = None
@@ -250,8 +249,8 @@ class Store(glance.store.base.Store):
     def _option_get(self, param):
         result = getattr(CONF, param)
         if not result:
-            reason = _("Could not find %(param)s in configuration "
-                       "options.") % locals()
+            reason = (_("Could not find %(param)s in configuration "
+                        "options.") % {'param': param})
             LOG.debug(reason)
             raise exception.BadStoreConfiguration(store_name="s3",
                                                   reason=reason)
@@ -325,7 +324,8 @@ class Store(glance.store.base.Store):
         :param image_file: The image data to write, as a file-like object
         :param image_size: The size of the image data to write, in bytes
 
-        :retval tuple of URL in backing store, bytes written, and checksum
+        :retval tuple of URL in backing store, bytes written, checksum
+                and a dictionary with storage system specific information
         :raises `glance.common.exception.Duplicate` if the image already
                 existed
 
@@ -412,9 +412,11 @@ class Store(glance.store.base.Store):
         checksum_hex = checksum.hexdigest()
 
         LOG.debug(_("Wrote %(size)d bytes to S3 key named %(obj_name)s "
-                    "with checksum %(checksum_hex)s") % locals())
+                    "with checksum %(checksum_hex)s"),
+                  {'size': size, 'obj_name': obj_name,
+                   'checksum_hex': checksum_hex})
 
-        return (loc.get_uri(), size, checksum_hex)
+        return (loc.get_uri(), size, checksum_hex, {})
 
     def delete(self, location):
         """
@@ -459,7 +461,7 @@ def get_bucket(conn, bucket_id):
 
     bucket = conn.get_bucket(bucket_id)
     if not bucket:
-        msg = _("Could not find bucket with ID %(bucket_id)s") % locals()
+        msg = _("Could not find bucket with ID %s") % bucket_id
         LOG.debug(msg)
         raise exception.NotFound(msg)
 
@@ -493,22 +495,22 @@ def create_bucket_if_missing(bucket, s3_conn):
     from boto.exception import S3ResponseError
     try:
         s3_conn.get_bucket(bucket)
-    except S3ResponseError, e:
+    except S3ResponseError as e:
         if e.status == httplib.NOT_FOUND:
             if CONF.s3_store_create_bucket_on_put:
                 location = get_s3_location(CONF.s3_store_host)
                 try:
                     s3_conn.create_bucket(bucket, location=location)
-                except S3ResponseError, e:
+                except S3ResponseError as e:
                     msg = (_("Failed to add bucket to S3.\n"
-                             "Got error from S3: %(e)s") % locals())
+                             "Got error from S3: %(e)s") % {'e': e})
                     raise glance.store.BackendException(msg)
             else:
                 msg = (_("The bucket %(bucket)s does not exist in "
                          "S3. Please set the "
                          "s3_store_create_bucket_on_put option "
                          "to add bucket to S3 automatically.")
-                       % locals())
+                       % {'bucket': bucket})
                 raise glance.store.BackendException(msg)
 
 
@@ -523,7 +525,8 @@ def get_key(bucket, obj):
 
     key = bucket.get_key(obj)
     if not key or not key.exists():
-        msg = _("Could not find key %(obj)s in bucket %(bucket)s") % locals()
+        msg = (_("Could not find key %(obj)s in bucket %(bucket)s") %
+               {'obj': obj, 'bucket': bucket})
         LOG.debug(msg)
         raise exception.NotFound(msg)
     return key
