@@ -13,21 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from glance.api import CONF
-import glance.db.registry.api
-from glance.db.sqlalchemy import api
-from glance.db.sqlalchemy import models as db_models
-import glance.tests.functional.db as db_tests
+import glance.db
 from glance.tests import functional
+import glance.tests.functional.db as db_tests
 from glance.tests.functional.db import base
 
 
 def get_db(config):
-    config(sql_connection='sqlite://', verbose=False, debug=False)
-    CONF.set_override('data_api', 'glance.db.registry.api')
-    db_api = glance.db.get_api()
-    db_api.setup_db_env()
-    return db_api
+    config(group='database', connection='sqlite://')
+    config(data_api='glance.db.registry.api')
+    return glance.db.get_api()
 
 
 def reset_db(db_api):
