@@ -1,4 +1,5 @@
 # Copyright 2012 OpenStack Foundation
+# Copyright 2013 IBM Corp.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -60,3 +61,11 @@ class TestSimpleMembershipVisibility(base.TestMembershipVisibility,
         db_tests.load(get_db, reset_db)
         super(TestSimpleMembershipVisibility, self).setUp()
         self.addCleanup(db_tests.reset)
+
+
+class TestSimpleTask(base.TaskTests):
+
+    def setUp(self):
+        db_tests.load(get_db, reset_db)
+        super(TestSimpleTask, self).setUp()
+        self.addCleanup(db_tests.reset)
