@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 OpenStack Foundation
 # All Rights Reserved.
 #
@@ -15,15 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import StringIO
+import uuid
 
 from oslo.config import cfg
+import six
 
-from glance.common import exception
-from glance.openstack.common import uuidutils
-import glance.store.location
 #NOTE(bcwaldon): importing this to get the default_store option
 import glance.api.v1.images
+from glance.common import exception
+
+import glance.store.location
 
 CONF = cfg.CONF
 
@@ -70,14 +69,14 @@ class BaseTestCase(object):
     def test_create_store(self):
         self.config(known_stores=[self.store_cls_path])
         count = glance.store.create_stores()
-        self.assertEqual(count, 1)
+        self.assertEqual(8, count)
 
     def test_lifecycle(self):
         """Add, get and delete an image"""
         store = self.get_store()
 
-        image_id = uuidutils.generate_uuid()
-        image_data = StringIO.StringIO('XXX')
+        image_id = str(uuid.uuid4())
+        image_data = six.StringIO('XXX')
         image_checksum = 'bc9189406be84ec297464a514221406d'
         try:
             uri, add_size, add_checksum, _ = store.add(image_id, image_data, 3)
@@ -90,10 +89,10 @@ class BaseTestCase(object):
 
         store = self.get_store()
         location = glance.store.location.Location(
-                self.store_name,
-                store.get_store_location_class(),
-                uri=uri,
-                image_id=image_id)
+            self.store_name,
+            store.get_store_location_class(),
+            uri=uri,
+            image_id=image_id)
 
         (get_iter, get_size) = store.get(location)
         self.assertEqual(3, get_size)
@@ -108,7 +107,7 @@ class BaseTestCase(object):
 
     def test_get_remote_image(self):
         """Get an image that was created externally to Glance"""
-        image_id = uuidutils.generate_uuid()
+        image_id = str(uuid.uuid4())
         try:
             image_uri = self.stash_image(image_id, 'XXX')
         except NotImplementedError:
@@ -117,9 +116,9 @@ class BaseTestCase(object):
 
         store = self.get_store()
         location = glance.store.location.Location(
-                self.store_name,
-                store.get_store_location_class(),
-                uri=image_uri)
+            self.store_name,
+            store.get_store_location_class(),
+            uri=image_uri)
 
         (get_iter, get_size) = store.get(location)
         self.assertEqual(3, get_size)
