@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack, LLC
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,14 +18,18 @@
 import datetime
 import hashlib
 import httplib2
-import json
 import os
 import sys
 
-from glance.tests import functional
-from glance.tests.utils import execute, minimal_headers
+from six.moves import xrange
 
-FIVE_KB = 5 * 1024
+from glance.openstack.common import jsonutils
+from glance.openstack.common import units
+from glance.tests import functional
+from glance.tests.utils import execute
+from glance.tests.utils import minimal_headers
+
+FIVE_KB = 5 * units.Ki
 
 
 class TestBinGlanceCacheManage(functional.FunctionalTest):
@@ -59,7 +61,7 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
         self.assertEqual(response.status, 201)
-        data = json.loads(content)
+        data = jsonutils.loads(content)
         self.assertEqual(data['image']['checksum'],
                          hashlib.md5(image_data).hexdigest())
         self.assertEqual(data['image']['size'], FIVE_KB)
@@ -134,7 +136,7 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
 
         # Add a few images and cache the second one of them
         # by GETing the image...
-        for x in xrange(0, 4):
+        for x in xrange(4):
             ids[x] = self.add_image("Image%s" % x)
 
         path = "http://%s:%d/v1/images/%s" % ("127.0.0.1", api_port,
@@ -181,12 +183,12 @@ class TestBinGlanceCacheManage(functional.FunctionalTest):
 
         # Add a few images and cache the second one of them
         # by GETing the image...
-        for x in xrange(0, 4):
+        for x in xrange(4):
             ids[x] = self.add_image("Image%s" % x)
 
         # Queue second image and then cache it
         cmd = "%s --port=%d --force queue-image %s" % (
-                exe_cmd, api_port, ids[1])
+            exe_cmd, api_port, ids[1])
 
         exitcode, out, err = execute(cmd)
 
@@ -248,7 +250,7 @@ log_file = %(log_file)s
 
         # Queue third image and then delete it from queue
         cmd = "%s --port=%d --force queue-image %s" % (
-                exe_cmd, api_port, ids[2])
+            exe_cmd, api_port, ids[2])
 
         exitcode, out, err = execute(cmd)
 
@@ -279,7 +281,7 @@ log_file = %(log_file)s
         self.assertTrue('No queued images' in out.strip())
 
         # Queue all images
-        for x in xrange(0, 4):
+        for x in xrange(4):
             cmd = ("%s --port=%d --force "
                    "queue-image %s") % (exe_cmd, api_port, ids[x])
 
@@ -311,4 +313,34 @@ log_file = %(log_file)s
         self.assertEqual(0, exitcode)
         self.assertTrue('No queued images' in out.strip())
 
+        # verify two image id when queue-image
+        cmd = ("%s --port=%d --force "
+               "queue-image %s %s") % (exe_cmd, api_port, ids[0], ids[1])
+
+        exitcode, out, err = execute(cmd, raise_error=False)
+
+        self.assertEqual(1, exitcode)
+        self.assertTrue('Please specify one and only ID of '
+                        'the image you wish to ' in out.strip())
+
+        # verify two image id when delete-queued-image
+        cmd = ("%s --port=%d --force delete-queued-image "
+               "%s %s") % (exe_cmd, api_port, ids[0], ids[1])
+
+        exitcode, out, err = execute(cmd, raise_error=False)
+
+        self.assertEqual(1, exitcode)
+        self.assertTrue('Please specify one and only ID of '
+                        'the image you wish to ' in out.strip())
+
+        # verify two image id when delete-cached-image
+        cmd = ("%s --port=%d --force delete-cached-image "
+               "%s %s") % (exe_cmd, api_port, ids[0], ids[1])
+
+        exitcode, out, err = execute(cmd, raise_error=False)
+
+        self.assertEqual(1, exitcode)
+        self.assertTrue('Please specify one and only ID of '
+                        'the image you wish to ' in out.strip())
+
         self.stop_servers()
