@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2012 Red Hat, Inc
 # All Rights Reserved.
 #
@@ -22,7 +20,9 @@ import sys
 
 from glance.common import utils
 from glance.tests import functional
-from glance.tests.utils import execute, depends_on_exe, skip_if_disabled
+from glance.tests.utils import depends_on_exe
+from glance.tests.utils import execute
+from glance.tests.utils import skip_if_disabled
 
 
 class TestGlanceManage(functional.FunctionalTest):
@@ -44,7 +44,7 @@ class TestGlanceManage(functional.FunctionalTest):
             conf_file.write(self.connection)
             conf_file.flush()
 
-        cmd = ('%s -m glance.cmd.manage --config-file %s db_sync' %
+        cmd = ('%s -m glance.cmd.manage --config-file %s db sync' %
                (sys.executable, self.conf_filepath))
         execute(cmd, raise_error=True)
 
@@ -58,8 +58,13 @@ class TestGlanceManage(functional.FunctionalTest):
 
         #NOTE(bcwaldon): For some reason we need double-quotes around
         # these two table names
-        self.assertTrue('CREATE TABLE "image_members"' in out)
-        self.assertTrue('CREATE TABLE "image_properties"' in out)
+        # NOTE(vsergeyev): There are some cases when we have no double-quotes
+        self.assertTrue(
+            'CREATE TABLE "image_members"' in out or
+            'CREATE TABLE image_members' in out)
+        self.assertTrue(
+            'CREATE TABLE "image_properties"' in out or
+            'CREATE TABLE image_properties' in out)
 
     @depends_on_exe('sqlite3')
     @skip_if_disabled
