@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack, LLC
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -17,15 +15,16 @@
 
 import hashlib
 import httplib2
-import json
 import os
-import tempfile
 
+from glance.openstack.common import jsonutils
+from glance.openstack.common import units
 from glance.tests import functional
-from glance.tests.utils import execute, minimal_headers, minimal_add_command
+from glance.tests.utils import execute
+from glance.tests.utils import minimal_headers
 
-FIVE_KB = 5 * 1024
-FIVE_GB = 5 * 1024 * 1024 * 1024
+FIVE_KB = 5 * units.Ki
+FIVE_GB = 5 * units.Gi
 
 
 class TestMiscellaneous(functional.FunctionalTest):
@@ -60,7 +59,7 @@ class TestMiscellaneous(functional.FunctionalTest):
         response, content = http.request(path, 'POST', headers=headers,
                                          body=image_data)
         self.assertEqual(response.status, 201)
-        data = json.loads(content)
+        data = jsonutils.loads(content)
         self.assertEqual(data['image']['checksum'],
                          hashlib.md5(image_data).hexdigest())
         self.assertEqual(data['image']['size'], FIVE_KB)
@@ -81,7 +80,7 @@ class TestMiscellaneous(functional.FunctionalTest):
         self.assertEqual(response['x-image-meta-name'], "Image1")
 
         # 4. GET /images/1
-        # Verify the api throws the apropriate 404 error
+        # Verify the api throws the appropriate 404 error
         path = "http://%s:%d/v1/images/1" % ("127.0.0.1", self.api_port)
         http = httplib2.Http()
         response, content = http.request(path, 'GET')
@@ -104,7 +103,6 @@ class TestMiscellaneous(functional.FunctionalTest):
         self.start_servers()
 
         api_port = self.api_port
-        registry_port = self.registry_port
 
         cmd = "curl -g http://127.0.0.1:%d/v1/images" % api_port
 
@@ -124,39 +122,3 @@ class TestMiscellaneous(functional.FunctionalTest):
                         "in output: %s" % out)
 
         self.stop_servers()
-
-    def test_api_treats_size_as_a_normal_property(self):
-        """
-        A test for LP bug #825024 -- glance client currently
-        treats size as a normal property.
-        """
-
-        self.cleanup()
-        self.start_servers()
-
-        # 1. POST /images with public image named Image1
-        # attribute and no custom properties. Verify a 200 OK is returned
-        with tempfile.NamedTemporaryFile() as image_file:
-            image_file.write("XXX")
-            image_file.flush()
-            image_file_name = image_file.name
-            suffix = 'size=12345 --silent-upload < %s' % image_file_name
-            cmd = minimal_add_command(self.api_port, 'MyImage', suffix)
-
-            exitcode, out, err = execute(cmd)
-
-        image_id = out.strip().split(':')[1].strip()
-        self.assertEqual(0, exitcode)
-        self.assertTrue('Found non-settable field size. Removing.' in out)
-        self.assertTrue('Added new image with ID: %s' % image_id in out)
-
-        # 2. Verify image added as public image
-        cmd = "bin/glance --port=%d show %s" % (self.api_port, image_id)
-
-        exitcode, out, err = execute(cmd)
-
-        self.assertEqual(0, exitcode)
-        lines = out.split("\n")[2:-1]
-        self.assertFalse("12345" in out)
-
-        self.stop_servers()
