@@ -14,12 +14,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import http.client as http
+import os
 import uuid
 
-from oslo_serialization import jsonutils
+import fixtures
 import requests
 
+from glance.openstack.common import jsonutils
 from glance.tests import functional
 
 
@@ -34,7 +35,12 @@ class TestTasks(functional.FunctionalTest):
     def setUp(self):
         super(TestTasks, self).setUp()
         self.cleanup()
+        self.file_path = self._stash_file()
         self.api_server.deployment_flavor = 'noauth'
+        self.start_servers(**self.__dict__.copy())
+
+    def _url(self, path):
+        return 'http://127.0.0.1:%d%s' % (self.api_port, path)
 
     def _headers(self, custom_headers=None):
         base_headers = {
@@ -42,25 +48,26 @@ class TestTasks(functional.FunctionalTest):
             'X-Auth-Token': '932c5c84-02ac-4fe5-a9ba-620af0e2bb96',
             'X-User-Id': 'f9a41d13-0c13-47e9-bee2-ce4e8bfe958e',
             'X-Tenant-Id': TENANT1,
-            'X-Roles': 'admin',
+            'X-Roles': 'member',
         }
         base_headers.update(custom_headers or {})
         return base_headers
 
-    def test_task_not_allowed_non_admin(self):
-        self.start_servers(**self.__dict__.copy())
-        roles = {'X-Roles': 'member'}
-        # Task list should be empty
-        path = self._url('/v2/tasks')
-        response = requests.get(path, headers=self._headers(roles))
-        self.assertEqual(http.FORBIDDEN, response.status_code)
+    def _stash_file(self):
+        self.tmp_dir = self.useFixture(fixtures.TempDir()).path
+        self.store_dir = os.path.join(self.tmp_dir, 'images')
+        os.mkdir(self.store_dir)
+
+        file_path = os.path.join(self.store_dir, 'foo')
+        with open(file_path, 'w') as f:
+            f.write('blah')
+        return 'file://%s' % file_path
 
     def test_task_lifecycle(self):
-        self.start_servers(**self.__dict__.copy())
         # Task list should be empty
         path = self._url('/v2/tasks')
         response = requests.get(path, headers=self._headers())
-        self.assertEqual(http.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         tasks = jsonutils.loads(response.text)['tasks']
         self.assertEqual(0, len(tasks))
 
@@ -71,7 +78,7 @@ class TestTasks(functional.FunctionalTest):
         data = jsonutils.dumps({
             "type": "import",
             "input": {
-                "import_from": "http://example.com",
+                "import_from": self.file_path,
                 "import_from_format": "qcow2",
                 "image_properties": {
                     'disk_format': 'vhd',
@@ -80,35 +87,30 @@ class TestTasks(functional.FunctionalTest):
             }
         })
         response = requests.post(path, headers=headers, data=data)
-        self.assertEqual(http.CREATED, response.status_code)
+        self.assertEqual(201, response.status_code)
 
         # Returned task entity should have a generated id and status
         task = jsonutils.loads(response.text)
         task_id = task['id']
 
-        self.assertIn('Location', response.headers)
+        self.assertTrue('Location' in response.headers)
         self.assertEqual(path + '/' + task_id, response.headers['Location'])
 
-        checked_keys = set(['created_at',
-                            'id',
-                            'input',
-                            'message',
-                            'owner',
-                            'schema',
-                            'self',
-                            'status',
-                            'type',
-                            'result',
-                            'updated_at',
-                            'request_id',
-                            'user_id'
-                            ])
-        self.assertEqual(checked_keys, set(task.keys()))
+        checked_keys = set([u'created_at',
+                            u'id',
+                            u'input',
+                            u'owner',
+                            u'schema',
+                            u'self',
+                            u'status',
+                            u'type',
+                            u'updated_at'])
+        self.assertEqual(set(task.keys()), checked_keys)
         expected_task = {
             'status': 'pending',
             'type': 'import',
             'input': {
-                "import_from": "http://example.com",
+                "import_from": self.file_path,
                 "import_from_format": "qcow2",
                 "image_properties": {
                     'disk_format': 'vhd',
@@ -117,20 +119,20 @@ class TestTasks(functional.FunctionalTest):
             'schema': '/v2/schemas/task',
         }
         for key, value in expected_task.items():
-            self.assertEqual(value, task[key], key)
+            self.assertEqual(task[key], value, key)
 
         # Tasks list should now have one entry
         path = self._url('/v2/tasks')
         response = requests.get(path, headers=self._headers())
-        self.assertEqual(http.OK, response.status_code)
+        self.assertEqual(200, response.status_code)
         tasks = jsonutils.loads(response.text)['tasks']
         self.assertEqual(1, len(tasks))
-        self.assertEqual(task_id, tasks[0]['id'])
+        self.assertEqual(tasks[0]['id'], task_id)
 
         # Attempt to delete a task
         path = self._url('/v2/tasks/%s' % tasks[0]['id'])
         response = requests.delete(path, headers=self._headers())
-        self.assertEqual(http.METHOD_NOT_ALLOWED, response.status_code)
+        self.assertEqual(405, response.status_code)
         self.assertIsNotNone(response.headers.get('Allow'))
         self.assertEqual('GET', response.headers.get('Allow'))
 
