@@ -13,13 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import http.client
-
-import eventlet
-from oslo_serialization import jsonutils as json
-from oslo_utils import timeutils
-
 from glance.api.v2 import tasks
+import glance.openstack.common.jsonutils as json
 from glance.tests.integration.v2 import base
 
 TENANT1 = '6838eb7b-6ded-434a-882c-b344c77fe8df'
@@ -40,7 +35,7 @@ def _new_task_fixture(**kwargs):
     task_data = {
         "type": "import",
         "input": {
-            "import_from": "http://example.com",
+            "import_from": "/some/file/path",
             "import_from_format": "qcow2",
             "image_properties": {
                 'disk_format': 'vhd',
@@ -57,47 +52,12 @@ class TestTasksApi(base.ApiTest):
     def __init__(self, *args, **kwargs):
         super(TestTasksApi, self).__init__(*args, **kwargs)
         self.api_flavor = 'fakeauth'
-
-    def _wait_on_task_execution(self, max_wait=5):
-        """Wait until all the tasks have finished execution and are in
-        state of success or failure.
-        """
-
-        start = timeutils.utcnow()
-
-        # wait for maximum of seconds defined by max_wait
-        while timeutils.delta_seconds(start, timeutils.utcnow()) < max_wait:
-            wait = False
-            # Verify that no task is in status of pending or processing
-            path = "/v2/tasks"
-            res, content = self.http.request(path, 'GET',
-                                             headers=minimal_task_headers())
-            content_dict = json.loads(content)
-
-            self.assertEqual(http.client.OK, res.status)
-            res_tasks = content_dict['tasks']
-            if len(res_tasks) != 0:
-                for task in res_tasks:
-                    if task['status'] in ('pending', 'processing'):
-                        wait = True
-                        break
-
-            if wait:
-                # Bug #1541487: we must give time to the server to execute the
-                # task, but the server is run in the same process than the
-                # test. Use eventlet to give the control to the pending server
-                # task.
-                eventlet.sleep(0.05)
-                continue
-            else:
-                break
+        self.registry_flavor = 'fakeauth'
 
     def _post_new_task(self, **kwargs):
-        task_owner = kwargs.get('owner')
+        task_owner = kwargs['owner']
         headers = minimal_task_headers(task_owner)
-
         task_data = _new_task_fixture()
-        task_data['input']['import_from'] = "http://example.com"
         body_content = json.dumps(task_data)
 
         path = "/v2/tasks"
@@ -105,19 +65,10 @@ class TestTasksApi(base.ApiTest):
                                               headers=headers,
                                               body=body_content)
 
-        self.assertEqual(http.client.CREATED, response.status)
+        self.assertEqual(response.status, 201)
 
         task = json.loads(content)
-        task_id = task['id']
-
-        self.assertIsNotNone(task_id)
-        self.assertEqual(task_owner, task['owner'])
-        self.assertEqual(task_data['type'], task['type'])
-        self.assertEqual(task_data['input'], task['input'])
-        self.assertEqual("http://localhost" + path + "/" + task_id,
-                         response.webob_resp.headers['Location'])
-
-        return task, task_data
+        return task
 
     def test_all_task_api(self):
         # 0. GET /tasks
@@ -127,7 +78,7 @@ class TestTasksApi(base.ApiTest):
                                               headers=minimal_task_headers())
         content_dict = json.loads(content)
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
         self.assertFalse(content_dict['tasks'])
 
         # 1. GET /tasks/{task_id}
@@ -137,45 +88,56 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.NOT_FOUND, response.status)
+        self.assertEqual(response.status, 404)
 
         # 2. POST /tasks
         # Create a new task
+        task_data = _new_task_fixture()
         task_owner = 'tenant1'
-        data, req_input = self._post_new_task(owner=task_owner)
+        body_content = json.dumps(task_data)
+
+        path = "/v2/tasks"
+        response, content = self.http.request(path, 'POST',
+                                              headers=
+                                              minimal_task_headers(task_owner),
+                                              body=body_content)
+        self.assertEqual(response.status, 201)
+
+        data = json.loads(content)
+        task_id = data['id']
+
+        self.assertIsNotNone(task_id)
+        self.assertEqual(task_owner, data['owner'])
+        self.assertEqual(task_data['type'], data['type'])
+        self.assertEqual(task_data['input'], data['input'])
 
         # 3. GET /tasks/{task_id}
         # Get an existing task
-        task_id = data['id']
         path = "/v2/tasks/%s" % task_id
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
-        # NOTE(sabari): wait for all task executions to finish before checking
-        # task status.
-        self._wait_on_task_execution(max_wait=10)
-
-        # 4. GET /tasks
+        # 4. GET /tasks/{task_id}
         # Get all tasks (not deleted)
         path = "/v2/tasks"
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
         self.assertIsNotNone(content)
 
         data = json.loads(content)
         self.assertIsNotNone(data)
         self.assertEqual(1, len(data['tasks']))
-        # NOTE(venkatesh) find a way to get expected_keys from tasks controller
-        expected_keys = set(['id', 'expires_at', 'type', 'owner', 'status',
+        #NOTE(venkatesh) find a way to get expected_keys from tasks controller
+        expected_keys = set(['id', 'type', 'owner', 'status',
                              'created_at', 'updated_at', 'self', 'schema'])
         task = data['tasks'][0]
         self.assertEqual(expected_keys, set(task.keys()))
-        self.assertEqual(req_input['type'], task['type'])
+        self.assertEqual(task_data['type'], task['type'])
         self.assertEqual(task_owner, task['owner'])
-        self.assertEqual('success', task['status'])
+        self.assertEqual('pending', task['status'])
         self.assertIsNotNone(task['created_at'])
         self.assertIsNotNone(task['updated_at'])
 
@@ -185,7 +147,7 @@ class TestTasksApi(base.ApiTest):
         path = "/v2/schemas/task"
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         schema = tasks.get_task_schema()
         expected_schema = schema.minimal()
@@ -198,7 +160,7 @@ class TestTasksApi(base.ApiTest):
         path = "/v2/schemas/tasks"
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         schema = tasks.get_collection_schema()
         expected_schema = schema.minimal()
@@ -206,10 +168,6 @@ class TestTasksApi(base.ApiTest):
         self.assertIsNotNone(data)
         self.assertEqual(expected_schema, data)
 
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
-
     def test_create_new_task(self):
         # 0. POST /tasks
         # Create a new task with valid input and type
@@ -218,10 +176,11 @@ class TestTasksApi(base.ApiTest):
         body_content = json.dumps(task_data)
 
         path = "/v2/tasks"
-        response, content = self.http.request(
-            path, 'POST', headers=minimal_task_headers(task_owner),
-            body=body_content)
-        self.assertEqual(http.client.CREATED, response.status)
+        response, content = self.http.request(path, 'POST',
+                                              headers=
+                                              minimal_task_headers(task_owner),
+                                              body=body_content)
+        self.assertEqual(response.status, 201)
 
         data = json.loads(content)
         task_id = data['id']
@@ -239,27 +198,25 @@ class TestTasksApi(base.ApiTest):
         body_content = json.dumps(task_data)
 
         path = "/v2/tasks"
-        response, content = self.http.request(
-            path, 'POST', headers=minimal_task_headers(task_owner),
-            body=body_content)
-        self.assertEqual(http.client.BAD_REQUEST, response.status)
+        response, content = self.http.request(path, 'POST',
+                                              headers=
+                                              minimal_task_headers(task_owner),
+                                              body=body_content)
+        self.assertEqual(response.status, 400)
 
         # 1. POST /tasks
         # Create a new task with invalid input for type 'import'
         # Expect BadRequest(400) Error as response
-        task_data = _new_task_fixture(task_input='{something: invalid}')
+        task_data = _new_task_fixture(input='{something: invalid}')
         task_owner = 'tenant1'
         body_content = json.dumps(task_data)
 
         path = "/v2/tasks"
-        response, content = self.http.request(
-            path, 'POST', headers=minimal_task_headers(task_owner),
-            body=body_content)
-        self.assertEqual(http.client.BAD_REQUEST, response.status)
-
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
+        response, content = self.http.request(path, 'POST',
+                                              headers=
+                                              minimal_task_headers(task_owner),
+                                              body=body_content)
+        self.assertEqual(response.status, 400)
 
     def test_tasks_with_filter(self):
 
@@ -269,20 +226,37 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         content_dict = json.loads(content)
         self.assertFalse(content_dict['tasks'])
 
         task_ids = []
 
-        # 1. Make 2 POST requests on /tasks with various attributes
+        # 1. POST /tasks with two tasks with status 'pending' and 'processing'
+        # with various attributes
         task_owner = TENANT1
-        data, req_input1 = self._post_new_task(owner=task_owner)
+        headers = minimal_task_headers(task_owner)
+        task_data = _new_task_fixture()
+        body_content = json.dumps(task_data)
+        path = "/v2/tasks"
+        response, content = self.http.request(path, 'POST',
+                                              headers=headers,
+                                              body=body_content)
+        self.assertEqual(response.status, 201)
+        data = json.loads(content)
         task_ids.append(data['id'])
 
         task_owner = TENANT2
-        data, req_input2 = self._post_new_task(owner=task_owner)
+        headers = minimal_task_headers(task_owner)
+        task_data = _new_task_fixture()
+        body_content = json.dumps(task_data)
+        path = "/v2/tasks"
+        response, content = self.http.request(path, 'POST',
+                                              headers=headers,
+                                              body=body_content)
+        self.assertEqual(response.status, 201)
+        data = json.loads(content)
         task_ids.append(data['id'])
 
         # 2. GET /tasks
@@ -291,7 +265,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         content_dict = json.loads(content)
         self.assertEqual(2, len(content_dict['tasks']))
@@ -304,7 +278,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         content_dict = json.loads(content)
         self.assertEqual(1, len(content_dict['tasks']))
@@ -317,7 +291,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         content_dict = json.loads(content)
         self.assertEqual(1, len(content_dict['tasks']))
@@ -330,7 +304,7 @@ class TestTasksApi(base.ApiTest):
 
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         content_dict = json.loads(content)
         self.assertEqual(2, len(content_dict['tasks']))
@@ -338,9 +312,32 @@ class TestTasksApi(base.ApiTest):
         actual_task_ids = [task['id'] for task in content_dict['tasks']]
         self.assertEqual(set(task_ids), set(actual_task_ids))
 
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
+        # 5. GET /tasks with status filter
+        # Verify correct tasks are returned for status 'pending'
+        params = "status=pending"
+        path = "/v2/tasks?%s" % params
+
+        response, content = self.http.request(path, 'GET',
+                                              headers=minimal_task_headers())
+        self.assertEqual(response.status, 200)
+
+        content_dict = json.loads(content)
+        self.assertEqual(2, len(content_dict['tasks']))
+
+        actual_task_ids = [task['id'] for task in content_dict['tasks']]
+        self.assertEqual(set(task_ids), set(actual_task_ids))
+
+        # 6. GET /tasks with status filter
+        # Verify no task are returned for status which is not 'pending'
+        params = "status=success"
+        path = "/v2/tasks?%s" % params
+
+        response, content = self.http.request(path, 'GET',
+                                              headers=minimal_task_headers())
+        self.assertEqual(response.status, 200)
+
+        content_dict = json.loads(content)
+        self.assertEqual(0, len(content_dict['tasks']))
 
     def test_limited_tasks(self):
         """
@@ -352,7 +349,7 @@ class TestTasksApi(base.ApiTest):
         path = "/v2/tasks"
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
         tasks = json.loads(content)
         self.assertFalse(tasks['tasks'])
 
@@ -360,13 +357,13 @@ class TestTasksApi(base.ApiTest):
 
         # 1. POST /tasks with three tasks with various attributes
 
-        task, _ = self._post_new_task(owner=TENANT1)
+        task = self._post_new_task(owner=TENANT1)
         task_ids.append(task['id'])
 
-        task, _ = self._post_new_task(owner=TENANT2)
+        task = self._post_new_task(owner=TENANT2)
         task_ids.append(task['id'])
 
-        task, _ = self._post_new_task(owner=TENANT3)
+        task = self._post_new_task(owner=TENANT3)
         task_ids.append(task['id'])
 
         # 2. GET /tasks
@@ -375,7 +372,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         tasks = json.loads(content)['tasks']
 
@@ -388,7 +385,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
 
@@ -403,7 +400,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
 
@@ -418,37 +415,33 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
 
         self.assertEqual(1, len(actual_tasks))
         self.assertEqual(tasks[2]['id'], actual_tasks[0]['id'])
 
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
-
     def test_ordered_tasks(self):
         # 0. GET /tasks
         # Verify no tasks
         path = "/v2/tasks"
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
         tasks = json.loads(content)
         self.assertFalse(tasks['tasks'])
 
         task_ids = []
 
         # 1. POST /tasks with three tasks with various attributes
-        task, _ = self._post_new_task(owner=TENANT1)
+        task = self._post_new_task(owner=TENANT1)
         task_ids.append(task['id'])
 
-        task, _ = self._post_new_task(owner=TENANT2)
+        task = self._post_new_task(owner=TENANT2)
         task_ids.append(task['id'])
 
-        task, _ = self._post_new_task(owner=TENANT3)
+        task = self._post_new_task(owner=TENANT3)
         task_ids.append(task['id'])
 
         # 2. GET /tasks with no query params
@@ -459,7 +452,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
 
@@ -474,7 +467,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         expected_task_owners = [TENANT1, TENANT2, TENANT3]
         expected_task_owners.sort()
@@ -490,7 +483,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
         self.assertEqual(2, len(actual_tasks))
@@ -506,16 +499,12 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path, 'GET',
                                               headers=minimal_task_headers())
 
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
 
         actual_tasks = json.loads(content)['tasks']
 
         self.assertEqual(0, len(actual_tasks))
 
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
-
     def test_delete_task(self):
         # 0. POST /tasks
         # Create a new task with valid input and type
@@ -524,10 +513,11 @@ class TestTasksApi(base.ApiTest):
         body_content = json.dumps(task_data)
 
         path = "/v2/tasks"
-        response, content = self.http.request(
-            path, 'POST', headers=minimal_task_headers(task_owner),
-            body=body_content)
-        self.assertEqual(http.client.CREATED, response.status)
+        response, content = self.http.request(path, 'POST',
+                                              headers=
+                                              minimal_task_headers(task_owner),
+                                              body=body_content)
+        self.assertEqual(response.status, 201)
 
         data = json.loads(content)
         task_id = data['id']
@@ -538,7 +528,7 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path,
                                               'DELETE',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.METHOD_NOT_ALLOWED, response.status)
+        self.assertEqual(response.status, 405)
         self.assertEqual('GET', response.webob_resp.headers.get('Allow'))
         self.assertEqual(('GET',), response.webob_resp.allow)
         self.assertEqual(('GET',), response.allow)
@@ -549,9 +539,5 @@ class TestTasksApi(base.ApiTest):
         response, content = self.http.request(path,
                                               'GET',
                                               headers=minimal_task_headers())
-        self.assertEqual(http.client.OK, response.status)
+        self.assertEqual(response.status, 200)
         self.assertIsNotNone(content)
-
-        # NOTE(nikhil): wait for all task executions to finish before exiting
-        # else there is a risk of running into deadlock
-        self._wait_on_task_execution()
