@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2010-2011 OpenStack, LLC
+# Copyright 2010-2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -41,8 +39,13 @@ DEBUG = False
 
 class FakeRegistryConnection(object):
 
-    def __init__(self, *args, **kwargs):
-        pass
+    def __init__(self, registry=None):
+        self.registry = registry or rserver
+
+    def __call__(self, *args, **kwargs):
+        # NOTE(flaper87): This method takes
+        # __init__'s place in the chain.
+        return self
 
     def connect(self):
         return True
@@ -60,7 +63,7 @@ class FakeRegistryConnection(object):
 
     def getresponse(self):
         mapper = routes.Mapper()
-        server = rserver.API(mapper)
+        server = self.registry.API(mapper)
         # NOTE(markwash): we need to pass through context auth information if
         # we have it.
         if 'X-Auth-Token' in self.req.headers:
@@ -74,7 +77,7 @@ class FakeRegistryConnection(object):
                                       data=webob_res.body)
 
 
-def stub_out_registry_and_store_server(stubs, base_dir):
+def stub_out_registry_and_store_server(stubs, base_dir, **kwargs):
     """
     Mocks calls to 127.0.0.1 on 9191 and 9292 for testing so
     that a real Glance server does not need to be up and
@@ -167,11 +170,12 @@ def stub_out_registry_and_store_server(stubs, base_dir):
         DEFAULT_API_PORT = 9292
 
         if (client.port == DEFAULT_API_PORT and
-            client.host == '0.0.0.0'):
+                client.host == '0.0.0.0'):
             return FakeGlanceConnection
         elif (client.port == DEFAULT_REGISTRY_PORT and
               client.host == '0.0.0.0'):
-            return FakeRegistryConnection
+            rserver = kwargs.get("registry", None)
+            return FakeRegistryConnection(registry=rserver)
 
     def fake_image_iter(self):
         for i in self.source.app_iter:
@@ -189,11 +193,9 @@ def stub_out_registry_and_store_server(stubs, base_dir):
     stubs.Set(glance.common.client.BaseClient, 'get_connection_type',
               fake_get_connection_type)
     setattr(glance.common.client.BaseClient, '_stub_orig_sendable',
-              glance.common.client.BaseClient._sendable)
+            glance.common.client.BaseClient._sendable)
     stubs.Set(glance.common.client.BaseClient, '_sendable',
               fake_sendable)
-    stubs.Set(glance.common.client.ImageBodyIterator, '__iter__',
-              fake_image_iter)
 
 
 def stub_out_registry_server(stubs, **kwargs):
@@ -209,8 +211,9 @@ def stub_out_registry_server(stubs, **kwargs):
         DEFAULT_REGISTRY_PORT = 9191
 
         if (client.port == DEFAULT_REGISTRY_PORT and
-            client.host == '0.0.0.0'):
-            return FakeRegistryConnection
+                client.host == '0.0.0.0'):
+            rserver = kwargs.pop("registry", None)
+            return FakeRegistryConnection(registry=rserver)
 
     def fake_image_iter(self):
         for i in self.response.app_iter:
@@ -218,5 +221,3 @@ def stub_out_registry_server(stubs, **kwargs):
 
     stubs.Set(glance.common.client.BaseClient, 'get_connection_type',
               fake_get_connection_type)
-    stubs.Set(glance.common.client.ImageBodyIterator, '__iter__',
-              fake_image_iter)
