@@ -13,7 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import stubout
 import testtools
 import webob
 
@@ -78,7 +77,7 @@ class TestCacheMiddlewareRequestStashCacheInfo(testtools.TestCase):
 
     def test_fetch_cache_request_info_unset(self):
         out = self.middleware._fetch_request_info(self.request)
-        self.assertEqual(out, None)
+        self.assertIsNone(out)
 
 
 class ChecksumTestCacheFilter(glance.api.middleware.cache.CacheFilter):
@@ -122,7 +121,7 @@ class TestCacheMiddlewareChecksumVerification(base.IsolatedUnitTest):
         resp = webob.Response(request=self.request)
         cache_filter._process_GET_response(resp, None)
 
-        self.assertEqual(None, cache_filter.cache.image_checksum)
+        self.assertIsNone(cache_filter.cache.image_checksum)
 
 
 class FakeImageSerializer(object):
@@ -211,7 +210,7 @@ class TestCacheMiddlewareProcessRequest(base.IsolatedUnitTest):
                        fake_get_image_metadata)
         actual = cache_filter._process_v1_request(
             request, image_id, dummy_img_iterator)
-        self.assertEqual(True, actual)
+        self.assertTrue(actual)
 
     def test_v1_remove_location_image_fetch(self):
 
@@ -273,23 +272,24 @@ class TestCacheMiddlewareProcessRequest(base.IsolatedUnitTest):
 
         def fake_image_get(self, image_id):
             return {
-                    'id': 'test1',
-                    'name': 'fake_image',
-                    'status': 'Active',
-                    'created_at': '',
-                    'min_disk': '10G',
-                    'min_ram': '1024M',
-                    'protected': False,
-                    'locations': '',
-                    'checksum': 'c352f4e7121c6eae958bc1570324f17e',
-                    'owner': '',
-                    'disk_format': 'raw',
-                    'container_format': 'bare',
-                    'size': '123456789',
-                    'is_public': 'public',
-                    'deleted': False,
-                    'updated_at': '',
-                    'properties': {},
+                'id': 'test1',
+                'name': 'fake_image',
+                'status': 'active',
+                'created_at': '',
+                'min_disk': '10G',
+                'min_ram': '1024M',
+                'protected': False,
+                'locations': '',
+                'checksum': 'c352f4e7121c6eae958bc1570324f17e',
+                'owner': '',
+                'disk_format': 'raw',
+                'container_format': 'bare',
+                'size': '123456789',
+                'virtual_size': '123456789',
+                'is_public': 'public',
+                'deleted': False,
+                'updated_at': '',
+                'properties': {},
             }
 
         def fake_image_tag_get_all(context, image_id, session=None):
@@ -327,7 +327,7 @@ class TestCacheMiddlewareProcessRequest(base.IsolatedUnitTest):
         self.set_policy_rules(rules)
         cache_filter.policy = glance.api.policy.Enforcer()
 
-        self.assertEqual(None, cache_filter.process_request(request))
+        self.assertIsNone(cache_filter.process_request(request))
 
 
 class TestCacheMiddlewareProcessResponse(base.IsolatedUnitTest):
