@@ -12,9 +12,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import os
 
 import mock
+import os
 
 from glance.common import exception
 from glance.image_cache import client
@@ -34,24 +34,24 @@ class CacheClientTestCase(utils.BaseTestCase):
                                                   "/cached_images/test_id")
 
     def test_get_cached_images(self):
-        expected_data = b'{"cached_images": "some_images"}'
-        self.client.do_request.return_value = utils.FakeHTTPResponse(
-            data=expected_data)
-        self.assertEqual("some_images", self.client.get_cached_images())
+        expected_data = '{"cached_images": "some_images"}'
+        self.client.do_request.return_value = \
+            utils.FakeHTTPResponse(data=expected_data)
+        self.assertEqual(self.client.get_cached_images(), "some_images")
         self.client.do_request.assert_called_with("GET", "/cached_images")
 
     def test_get_queued_images(self):
-        expected_data = b'{"queued_images": "some_images"}'
-        self.client.do_request.return_value = utils.FakeHTTPResponse(
-            data=expected_data)
-        self.assertEqual("some_images", self.client.get_queued_images())
+        expected_data = '{"queued_images": "some_images"}'
+        self.client.do_request.return_value = \
+            utils.FakeHTTPResponse(data=expected_data)
+        self.assertEqual(self.client.get_queued_images(), "some_images")
         self.client.do_request.assert_called_with("GET", "/queued_images")
 
     def test_delete_all_cached_images(self):
-        expected_data = b'{"num_deleted": 4}'
-        self.client.do_request.return_value = utils.FakeHTTPResponse(
-            data=expected_data)
-        self.assertEqual(4, self.client.delete_all_cached_images())
+        expected_data = '{"num_deleted": 4}'
+        self.client.do_request.return_value = \
+            utils.FakeHTTPResponse(data=expected_data)
+        self.assertEqual(self.client.delete_all_cached_images(), 4)
         self.client.do_request.assert_called_with("DELETE", "/cached_images")
 
     def test_queue_image_for_caching(self):
@@ -67,10 +67,10 @@ class CacheClientTestCase(utils.BaseTestCase):
                                                   "/queued_images/test_id")
 
     def test_delete_all_queued_images(self):
-        expected_data = b'{"num_deleted": 4}'
-        self.client.do_request.return_value = utils.FakeHTTPResponse(
-            data=expected_data)
-        self.assertEqual(4, self.client.delete_all_queued_images())
+        expected_data = '{"num_deleted": 4}'
+        self.client.do_request.return_value = \
+            utils.FakeHTTPResponse(data=expected_data)
+        self.assertEqual(self.client.delete_all_queued_images(), 4)
         self.client.do_request.assert_called_with("DELETE", "/queued_images")
 
 
@@ -78,23 +78,17 @@ class GetClientTestCase(utils.BaseTestCase):
     def setUp(self):
         super(GetClientTestCase, self).setUp()
         self.host = 'test_host'
-        self.env = os.environ.copy()
-        os.environ.clear()
-
-    def tearDown(self):
-        os.environ = self.env
-        super(GetClientTestCase, self).tearDown()
 
     def test_get_client_host_only(self):
         expected_creds = {
             'username': None,
             'password': None,
             'tenant': None,
-            'auth_url': None,
+            'auth_url': os.getenv('OS_AUTH_URL'),
             'strategy': 'noauth',
             'region': None
         }
-        self.assertEqual(expected_creds, client.get_client(self.host).creds)
+        self.assertEqual(client.get_client(self.host).creds, expected_creds)
 
     def test_get_client_all_creds(self):
         expected_creds = {
@@ -114,16 +108,7 @@ class GetClientTestCase(utils.BaseTestCase):
             auth_strategy='strategy',
             region='reg'
         ).creds
-        self.assertEqual(expected_creds, creds)
-
-    def test_get_client_using_provided_host(self):
-        cli = client.get_client(self.host)
-        cli._do_request = mock.MagicMock()
-        cli.configure_from_url = mock.MagicMock()
-        cli.auth_plugin.management_url = mock.MagicMock()
-        cli.do_request("GET", "/queued_images")
-        self.assertFalse(cli.configure_from_url.called)
-        self.assertFalse(client.get_client(self.host).configure_via_auth)
+        self.assertEqual(creds, expected_creds)
 
     def test_get_client_client_configuration_error(self):
         self.assertRaises(exception.ClientConfigurationError,
