@@ -1,6 +1,4 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2010-2011 OpenStack, LLC
+# Copyright 2010-2011 OpenStack Foundation
 # All Rights Reserved.
 # Copyright 2013 IBM Corp.
 #
@@ -25,27 +23,35 @@ properly both upgrading and downgrading, and that no data loss occurs
 if possible.
 """
 
-import commands
+from __future__ import print_function
+
 import ConfigParser
 import datetime
-import json
+import exceptions
 import os
 import pickle
-import urlparse
+import subprocess
+import uuid
 
+from migrate.versioning import api as migration_api
 from migrate.versioning.repository import Repository
 from oslo.config import cfg
+import six.moves.urllib.parse as urlparse
+from six.moves import xrange
 import sqlalchemy
 
 from glance.common import crypt
+from glance.common import exception
+from glance.common import utils
 import glance.db.migration as migration
 import glance.db.sqlalchemy.migrate_repo
-from glance.db.sqlalchemy.migration import versioning_api as migration_api
+from glance.db.sqlalchemy.migrate_repo.schema import from_migration_import
 from glance.db.sqlalchemy import models
+from glance.openstack.common import jsonutils
 from glance.openstack.common import log as logging
 from glance.openstack.common import timeutils
-from glance.openstack.common import uuidutils
-from glance.tests import utils
+
+from glance.tests import utils as test_utils
 
 
 CONF = cfg.CONF
@@ -68,7 +74,8 @@ def _get_connect_string(backend,
         backend = "postgresql+psycopg2"
 
     return ("%(backend)s://%(user)s:%(passwd)s@localhost/%(database)s"
-            % locals())
+            % {'backend': backend, 'user': user, 'passwd': passwd,
+               'database': database})
 
 
 def _is_backend_avail(backend,
@@ -105,13 +112,14 @@ def get_table(engine, name):
     """Returns an sqlalchemy table dynamically from db.
 
     Needed because the models don't work for us in migrations
-    as models will be far out of sync with the current data."""
+    as models will be far out of sync with the current data.
+    """
     metadata = sqlalchemy.schema.MetaData()
     metadata.bind = engine
     return sqlalchemy.Table(name, metadata, autoload=True)
 
 
-class TestMigrations(utils.BaseTestCase):
+class TestMigrations(test_utils.BaseTestCase):
     """Test sqlalchemy-migrate migrations."""
 
     DEFAULT_CONFIG_FILE = os.path.join(os.path.dirname(__file__),
@@ -163,9 +171,12 @@ class TestMigrations(utils.BaseTestCase):
 
     def _reset_databases(self):
         def execute_cmd(cmd=None):
-            status, output = commands.getstatusoutput(cmd)
+            proc = subprocess.Popen(cmd, stdout=subprocess.PIPE,
+                                    stderr=subprocess.STDOUT, shell=True)
+            output = proc.communicate()[0]
             LOG.debug(output)
-            self.assertEqual(0, status)
+            self.assertEqual(0, proc.returncode)
+
         for key, engine in self.engines.items():
             conn_string = self.test_databases[key]
             conn_pieces = urlparse.urlparse(conn_string)
@@ -173,7 +184,7 @@ class TestMigrations(utils.BaseTestCase):
             if conn_string.startswith('sqlite'):
                 # We can just delete the SQLite database, which is
                 # the easiest and cleanest solution
-                db_path = conn_pieces.path.strip('/')
+                db_path = conn_pieces.path[1:]
                 if os.path.exists(db_path):
                     os.unlink(db_path)
                 # No need to recreate the SQLite DB. SQLite will
@@ -191,10 +202,11 @@ class TestMigrations(utils.BaseTestCase):
                 if len(auth_pieces) > 1:
                     if auth_pieces[1].strip():
                         password = "-p\"%s\"" % auth_pieces[1]
-                sql = ("drop database if exists %(database)s; "
-                       "create database %(database)s;") % locals()
+                sql = ("drop database if exists %(database)s; create "
+                       "database %(database)s;") % {'database': database}
                 cmd = ("mysql -u \"%(user)s\" %(password)s -h %(host)s "
-                       "-e \"%(sql)s\"") % locals()
+                       "-e \"%(sql)s\"") % {'user': user, 'password': password,
+                                            'host': host, 'sql': sql}
                 execute_cmd(cmd)
             elif conn_string.startswith('postgresql'):
                 database = conn_pieces.path.strip('/')
@@ -209,18 +221,23 @@ class TestMigrations(utils.BaseTestCase):
                 # note(boris-42): This file is used for authentication
                 # without password prompt.
                 createpgpass = ("echo '*:*:*:%(user)s:%(password)s' > "
-                                "~/.pgpass && chmod 0600 ~/.pgpass" % locals())
+                                "~/.pgpass && chmod 0600 ~/.pgpass" %
+                                {'user': user, 'password': password})
                 execute_cmd(createpgpass)
                 # note(boris-42): We must create and drop database, we can't
                 # drop database which we have connected to, so for such
                 # operations there is a special database template1.
                 sqlcmd = ("psql -w -U %(user)s -h %(host)s -c"
                           " '%(sql)s' -d template1")
-                sql = ("drop database if exists %(database)s;") % locals()
-                droptable = sqlcmd % locals()
+                sql = ("drop database if exists %(database)s;")
+                sql = sql % {'database': database}
+                droptable = sqlcmd % {'user': user, 'host': host,
+                                      'sql': sql}
                 execute_cmd(droptable)
-                sql = ("create database %(database)s;") % locals()
-                createtable = sqlcmd % locals()
+                sql = ("create database %(database)s;")
+                sql = sql % {'database': database}
+                createtable = sqlcmd % {'user': user, 'host': host,
+                                        'sql': sql}
                 execute_cmd(createtable)
 
     def test_walk_versions(self):
@@ -450,7 +467,8 @@ class TestMigrations(utils.BaseTestCase):
 
     def _pre_upgrade_004(self, engine):
         """Insert checksum data sample to check if migration goes fine with
-        data"""
+        data.
+        """
         now = timeutils.utcnow()
         images = get_table(engine, 'images')
         data = [
@@ -466,7 +484,7 @@ class TestMigrations(utils.BaseTestCase):
         """Assure that checksum data is present on table"""
         images = get_table(engine, 'images')
         self.assertIn('checksum', images.c)
-        self.assertEquals(images.c['checksum'].type.length, 32)
+        self.assertEqual(images.c['checksum'].type.length, 32)
 
     def _pre_upgrade_005(self, engine):
         now = timeutils.utcnow()
@@ -528,7 +546,8 @@ class TestMigrations(utils.BaseTestCase):
 
     def _pre_upgrade_010(self, engine):
         """Test rows in images with NULL updated_at get updated to equal
-        created_at"""
+        created_at.
+        """
 
         initial_values = [
             (datetime.datetime(1999, 1, 2, 4, 10, 20),
@@ -571,7 +590,8 @@ class TestMigrations(utils.BaseTestCase):
     def _pre_upgrade_012(self, engine):
         """Test rows in images have id changes from int to varchar(32) and
         value changed from int to UUID. Also test image_members and
-        image_properties gets updated to point to new UUID keys"""
+        image_properties gets updated to point to new UUID keys.
+        """
 
         images = get_table(engine, 'images')
         image_members = get_table(engine, 'image_members')
@@ -622,11 +642,10 @@ class TestMigrations(utils.BaseTestCase):
                          .where(images.c.name == image_name)\
                          .execute().fetchall()
 
-            self.assertEquals(len(rows), 1)
+            self.assertEqual(len(rows), 1)
 
             row = rows[0]
-            print repr(dict(row))
-            self.assertTrue(uuidutils.is_uuid_like(row['id']))
+            self.assertTrue(utils.is_uuid_like(row['id']))
 
             uuids[name] = row['id']
 
@@ -635,7 +654,7 @@ class TestMigrations(utils.BaseTestCase):
                                .where(image_members.c.image_id ==
                                       uuids['normal'])\
                                .execute().fetchall()
-        self.assertEquals(len(results), 1)
+        self.assertEqual(len(results), 1)
 
         # Find all image_properties to ensure image_id has been updated
         # as well as ensure kernel_id and ramdisk_id values have been
@@ -644,7 +663,7 @@ class TestMigrations(utils.BaseTestCase):
                                   .where(image_properties.c.image_id ==
                                          uuids['normal'])\
                                   .execute().fetchall()
-        self.assertEquals(len(results), 2)
+        self.assertEqual(len(results), 2)
         for row in results:
             self.assertIn(row['name'], ('kernel_id', 'ramdisk_id'))
 
@@ -666,10 +685,10 @@ class TestMigrations(utils.BaseTestCase):
             rows = images.select()\
                          .where(images.c.name == image_name)\
                          .execute().fetchall()
-            self.assertEquals(len(rows), 1)
+            self.assertEqual(len(rows), 1)
 
             row = rows[0]
-            self.assertFalse(uuidutils.is_uuid_like(row['id']))
+            self.assertFalse(utils.is_uuid_like(row['id']))
 
             ids[name] = row['id']
 
@@ -678,7 +697,7 @@ class TestMigrations(utils.BaseTestCase):
                                .where(image_members.c.image_id ==
                                       ids['normal'])\
                                .execute().fetchall()
-        self.assertEquals(len(results), 1)
+        self.assertEqual(len(results), 1)
 
         # Find all image_properties to ensure image_id has been updated
         # as well as ensure kernel_id and ramdisk_id values have been
@@ -687,7 +706,7 @@ class TestMigrations(utils.BaseTestCase):
                                   .where(image_properties.c.image_id ==
                                          ids['normal'])\
                                   .execute().fetchall()
-        self.assertEquals(len(results), 2)
+        self.assertEqual(len(results), 2)
         for row in results:
             self.assertIn(row['name'], ('kernel_id', 'ramdisk_id'))
 
@@ -696,6 +715,72 @@ class TestMigrations(utils.BaseTestCase):
             if row['name'] == 'ramdisk_id':
                 self.assertEqual(row['value'], str(ids['ramdisk']))
 
+    def _assert_invalid_swift_uri_raises_bad_store_uri(self,
+                                                       legacy_parse_uri_fn):
+        invalid_uri = ('swift://http://acct:usr:pass@example.com'
+                       '/container/obj-id')
+        # URI cannot contain more than one occurrence of a scheme.
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_uri,
+                          True)
+
+        invalid_scheme_uri = ('http://acct:usr:pass@example.com'
+                              '/container/obj-id')
+        self.assertRaises(exceptions.AssertionError,
+                          legacy_parse_uri_fn,
+                          invalid_scheme_uri,
+                          True)
+
+        invalid_account_missing_uri = 'swift+http://container/obj-id'
+        # Badly formed S3 URI: swift+http://container/obj-id
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_account_missing_uri,
+                          True)
+
+        invalid_container_missing_uri = ('swift+http://'
+                                         'acct:usr:pass@example.com/obj-id')
+        # Badly formed S3 URI: swift+http://acct:usr:pass@example.com/obj-id
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_container_missing_uri,
+                          True)
+
+        invalid_object_missing_uri = ('swift+http://'
+                                      'acct:usr:pass@example.com/container')
+        # Badly formed S3 URI: swift+http://acct:usr:pass@example.com/container
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_object_missing_uri,
+                          True)
+
+        invalid_user_without_pass_uri = ('swift://acctusr@example.com'
+                                         '/container/obj-id')
+        # Badly formed credentials '%(creds)s' in Swift URI
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_user_without_pass_uri,
+                          True)
+
+        # Badly formed credentials in Swift URI.
+        self.assertRaises(exception.BadStoreUri,
+                          legacy_parse_uri_fn,
+                          invalid_user_without_pass_uri,
+                          False)
+
+    def test_legacy_parse_swift_uri_015(self):
+        (legacy_parse_uri,) = from_migration_import(
+            '015_quote_swift_credentials', ['legacy_parse_uri'])
+
+        uri = legacy_parse_uri(
+            'swift://acct:usr:pass@example.com/container/obj-id',
+            True)
+        self.assertTrue(uri, 'swift://acct%3Ausr:pass@example.com'
+                             '/container/obj-id')
+
+        self._assert_invalid_swift_uri_raises_bad_store_uri(legacy_parse_uri)
+
     def _pre_upgrade_015(self, engine):
         images = get_table(engine, 'images')
         unquoted_locations = [
@@ -712,7 +797,7 @@ class TestMigrations(utils.BaseTestCase):
                     min_ram=0)
         data = []
         for i, location in enumerate(unquoted_locations):
-            temp.update(location=location, id=uuidutils.generate_uuid())
+            temp.update(location=location, id=str(uuid.uuid4()))
             data.append(temp)
             images.insert().values(temp).execute()
         return data
@@ -758,14 +843,29 @@ class TestMigrations(utils.BaseTestCase):
                         "columns! image_members table columns: %s"
                         % image_members.c.keys())
 
+    def test_legacy_parse_swift_uri_017(self):
+        metadata_encryption_key = 'a' * 16
+        self.config(metadata_encryption_key=metadata_encryption_key)
+
+        (legacy_parse_uri, encrypt_location) = from_migration_import(
+            '017_quote_encrypted_swift_credentials', ['legacy_parse_uri',
+                                                      'encrypt_location'])
+
+        uri = legacy_parse_uri('swift://acct:usr:pass@example.com'
+                               '/container/obj-id', True)
+        self.assertTrue(uri, encrypt_location(
+            'swift://acct%3Ausr:pass@example.com/container/obj-id'))
+
+        self._assert_invalid_swift_uri_raises_bad_store_uri(legacy_parse_uri)
+
     def _pre_upgrade_017(self, engine):
         metadata_encryption_key = 'a' * 16
         self.config(metadata_encryption_key=metadata_encryption_key)
         images = get_table(engine, 'images')
         unquoted = 'swift://acct:usr:pass@example.com/container/obj-id'
         encrypted_unquoted = crypt.urlsafe_encrypt(
-                                    metadata_encryption_key,
-                                    unquoted, 64)
+            metadata_encryption_key,
+            unquoted, 64)
         data = []
         now = datetime.datetime.now()
         temp = dict(deleted=False,
@@ -794,7 +894,7 @@ class TestMigrations(utils.BaseTestCase):
                     min_disk=0,
                     min_ram=0)
         for i, location in enumerate(locations):
-            temp.update(location=location, id=uuidutils.generate_uuid())
+            temp.update(location=location, id=str(uuid.uuid4()))
             data.append(temp)
             images.insert().values(temp).execute()
         return data
@@ -823,20 +923,20 @@ class TestMigrations(utils.BaseTestCase):
                     'swift://acct3A%foobar:pass@example.com/container/obj-id2']
 
         for location in loc_list:
-            if not location in actual_location:
+            if location not in actual_location:
                 self.fail(_("location: %s data lost") % location)
 
     def _pre_upgrade_019(self, engine):
         images = get_table(engine, 'images')
         now = datetime.datetime.now()
         base_values = {
-                'deleted': False,
-                'created_at': now,
-                'updated_at': now,
-                'status': 'active',
-                'is_public': True,
-                'min_disk': 0,
-                'min_ram': 0,
+            'deleted': False,
+            'created_at': now,
+            'updated_at': now,
+            'status': 'active',
+            'is_public': True,
+            'min_disk': 0,
+            'min_ram': 0,
         }
         data = [
             {'id': 'fake-19-1', 'location': 'http://glance.example.com'},
@@ -892,8 +992,8 @@ class TestMigrations(utils.BaseTestCase):
             .where(image_locations.c.image_id == data).execute()
 
         r = list(results)
-        self.assertEquals(len(r), 1)
-        self.assertEquals(r[0]['value'], 'file:///some/place/onthe/fs')
+        self.assertEqual(len(r), 1)
+        self.assertEqual(r[0]['value'], 'file:///some/place/onthe/fs')
         self.assertTrue('meta_data' in r[0])
         x = pickle.loads(r[0]['meta_data'])
         self.assertEqual(x, {})
@@ -978,7 +1078,7 @@ class TestMigrations(utils.BaseTestCase):
             where(image_locations.c.image_id == image_id).execute().fetchall()
 
         for r in records:
-            d = json.loads(r['meta_data'])
+            d = jsonutils.loads(r['meta_data'])
             self.assertEqual(d, meta_data)
 
     def _post_downgrade_029(self, engine):
@@ -992,4 +1092,247 @@ class TestMigrations(utils.BaseTestCase):
         for r in records:
             md = r['meta_data']
             d = pickle.loads(md)
-            self.assertEqual(type(d), dict)
+            self.assertIsInstance(d, dict)
+
+    def _check_030(self, engine, data):
+        table = "tasks"
+        index_type = ('ix_tasks_type', ['type'])
+        index_status = ('ix_tasks_status', ['status'])
+        index_owner = ('ix_tasks_owner', ['owner'])
+        index_deleted = ('ix_tasks_deleted', ['deleted'])
+        index_updated_at = ('ix_tasks_updated_at', ['updated_at'])
+
+        meta = sqlalchemy.MetaData()
+        meta.bind = engine
+
+        tasks_table = sqlalchemy.Table(table, meta, autoload=True)
+
+        index_data = [(idx.name, idx.columns.keys())
+                      for idx in tasks_table.indexes]
+
+        self.assertIn(index_type, index_data)
+        self.assertIn(index_status, index_data)
+        self.assertIn(index_owner, index_data)
+        self.assertIn(index_deleted, index_data)
+        self.assertIn(index_updated_at, index_data)
+
+        expected = [u'id',
+                    u'type',
+                    u'status',
+                    u'owner',
+                    u'input',
+                    u'result',
+                    u'message',
+                    u'expires_at',
+                    u'created_at',
+                    u'updated_at',
+                    u'deleted_at',
+                    u'deleted']
+
+        # NOTE(flwang): Skip the column type checking for now since Jenkins is
+        # using sqlalchemy.dialects.postgresql.base.TIMESTAMP instead of
+        # DATETIME which is using by mysql and sqlite.
+        col_data = [col.name for col in tasks_table.columns]
+        self.assertEqual(expected, col_data)
+
+    def _post_downgrade_030(self, engine):
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'tasks')
+
+    def _pre_upgrade_031(self, engine):
+        images = get_table(engine, 'images')
+        now = datetime.datetime.now()
+        image_id = 'fake_031_id'
+        temp = dict(deleted=False,
+                    created_at=now,
+                    updated_at=now,
+                    status='active',
+                    is_public=True,
+                    min_disk=0,
+                    min_ram=0,
+                    id=image_id)
+        images.insert().values(temp).execute()
+
+        locations_table = get_table(engine, 'image_locations')
+        locations = [
+            ('file://ab', '{"a": "yo yo"}'),
+            ('file://ab', '{}'),
+            ('file://ab', '{}'),
+            ('file://ab1', '{"a": "that one, please"}'),
+            ('file://ab1', '{"a": "that one, please"}'),
+        ]
+        temp = dict(deleted=False,
+                    created_at=now,
+                    updated_at=now,
+                    image_id=image_id)
+
+        for location, metadata in locations:
+            temp.update(value=location, meta_data=metadata)
+            locations_table.insert().values(temp).execute()
+        return image_id
+
+    def _check_031(self, engine, image_id):
+        locations_table = get_table(engine, 'image_locations')
+        result = locations_table.select()\
+                                .where(locations_table.c.image_id == image_id)\
+                                .execute().fetchall()
+
+        locations = set([(x['value'], x['meta_data']) for x in result])
+        actual_locations = set([
+            ('file://ab', '{"a": "yo yo"}'),
+            ('file://ab', '{}'),
+            ('file://ab1', '{"a": "that one, please"}'),
+        ])
+        self.assertFalse(actual_locations.symmetric_difference(locations))
+
+    def _pre_upgrade_032(self, engine):
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'task_info')
+
+        tasks = get_table(engine, 'tasks')
+        now = datetime.datetime.now()
+        base_values = {
+            'deleted': False,
+            'created_at': now,
+            'updated_at': now,
+            'status': 'active',
+            'owner': 'TENANT',
+            'type': 'import',
+        }
+        data = [
+            {
+                'id': 'task-1',
+                'input': 'some input',
+                'message': None,
+                'result': 'successful'
+            },
+            {
+                'id': 'task-2',
+                'input': None,
+                'message': None,
+                'result': None
+            },
+        ]
+        map(lambda task: task.update(base_values), data)
+        for task in data:
+            tasks.insert().values(task).execute()
+        return data
+
+    def _check_032(self, engine, data):
+        task_info_table = get_table(engine, 'task_info')
+
+        task_info_refs = task_info_table.select().execute().fetchall()
+
+        self.assertEqual(len(task_info_refs), 2)
+
+        for x in range(len(task_info_refs)):
+            self.assertEqual(task_info_refs[x].task_id, data[x]['id'])
+            self.assertEqual(task_info_refs[x].input, data[x]['input'])
+            self.assertEqual(task_info_refs[x].result, data[x]['result'])
+            self.assertIsNone(task_info_refs[x].message)
+
+        tasks_table = get_table(engine, 'tasks')
+        self.assertNotIn('input', tasks_table.c)
+        self.assertNotIn('result', tasks_table.c)
+        self.assertNotIn('message', tasks_table.c)
+
+    def _post_downgrade_032(self, engine):
+        self.assertRaises(sqlalchemy.exc.NoSuchTableError,
+                          get_table, engine, 'task_info')
+
+        tasks_table = get_table(engine, 'tasks')
+        records = tasks_table.select().execute().fetchall()
+        self.assertEqual(len(records), 2)
+
+        tasks = dict([(t.id, t) for t in records])
+
+        task_1 = tasks.get('task-1')
+        self.assertEqual(task_1.input, 'some input')
+        self.assertEqual(task_1.result, 'successful')
+        self.assertIsNone(task_1.message)
+
+        task_2 = tasks.get('task-2')
+        self.assertIsNone(task_2.input)
+        self.assertIsNone(task_2.result)
+        self.assertIsNone(task_2.message)
+
+    def _pre_upgrade_033(self, engine):
+        images = get_table(engine, 'images')
+        image_locations = get_table(engine, 'image_locations')
+
+        now = datetime.datetime.now()
+        image_id = 'fake_id_028_%d'
+        url = 'file:///some/place/onthe/fs_%d'
+        status_list = ['active', 'saving', 'queued', 'killed',
+                       'pending_delete', 'deleted']
+        image_id_list = []
+
+        for (idx, status) in enumerate(status_list):
+            temp = dict(deleted=False,
+                        created_at=now,
+                        updated_at=now,
+                        status=status,
+                        is_public=True,
+                        min_disk=0,
+                        min_ram=0,
+                        id=image_id % idx)
+            images.insert().values(temp).execute()
+
+            temp = dict(deleted=False,
+                        created_at=now,
+                        updated_at=now,
+                        image_id=image_id % idx,
+                        value=url % idx)
+            image_locations.insert().values(temp).execute()
+
+            image_id_list.append(image_id % idx)
+        return image_id_list
+
+    def _check_033(self, engine, data):
+        image_locations = get_table(engine, 'image_locations')
+
+        self.assertIn('status', image_locations.c)
+        self.assertEqual(image_locations.c['status'].type.length, 30)
+
+        status_list = ['active', 'active', 'active',
+                       'deleted', 'pending_delete', 'deleted']
+
+        for (idx, image_id) in enumerate(data):
+            results = image_locations.select()\
+                .where(image_locations.c.image_id == image_id).execute()
+            r = list(results)
+            self.assertEqual(len(r), 1)
+            self.assertTrue('status' in r[0])
+            self.assertEqual(r[0]['status'], status_list[idx])
+
+    def _post_downgrade_033(self, engine):
+        image_locations = get_table(engine, 'image_locations')
+        self.assertNotIn('status', image_locations.c)
+
+    def _pre_upgrade_034(self, engine):
+        images = get_table(engine, 'images')
+
+        now = datetime.datetime.now()
+        image_id = 'fake_id_034'
+        temp = dict(deleted=False,
+                    created_at=now,
+                    updated_at=now,
+                    status='active',
+                    is_public=True,
+                    min_disk=0,
+                    min_ram=0,
+                    id=image_id)
+        images.insert().values(temp).execute()
+
+    def _check_034(self, engine, data):
+        images = get_table(engine, 'images')
+        self.assertIn('virtual_size', images.c)
+
+        result = (images.select()
+                  .where(images.c.id == 'fake_id_034')
+                  .execute().fetchone())
+        self.assertIsNone(result.virtual_size)
+
+    def _post_downgrade_034(self, engine):
+        images = get_table(engine, 'images')
+        self.assertNotIn('virtual_size', images.c)
