@@ -16,11 +16,12 @@ import mox
 
 from glance.common import exception
 import glance.store
+from glance.tests.unit import base as unit_test_base
 from glance.tests.unit import utils as unit_test_utils
 from glance.tests import utils
 
 
-BASE_URI = 'swift+http://storeurl.com/container'
+BASE_URI = 'http://storeurl.com/container'
 UUID1 = 'c80a1a6c-bd1f-41c5-90ee-81afedb1d58d'
 UUID2 = '971ec09a-8067-4bc8-a91f-ae3557f1c4c7'
 USER1 = '54492ba0-f4df-4e4e-be62-27f4d76b29cf'
@@ -33,7 +34,7 @@ class ImageRepoStub(object):
     def add(self, image):
         return image
 
-    def save(self, image):
+    def save(self, image, from_state=None):
         return image
 
 
@@ -44,6 +45,7 @@ class ImageStub(object):
         self.status = status
         self.locations = locations or []
         self.visibility = visibility
+        self.size = 1
 
     def delete(self):
         self.status = 'deleted'
@@ -88,24 +90,16 @@ class TestStoreImage(utils.BaseTestCase):
     def test_image_delete(self):
         image = glance.store.ImageProxy(self.image_stub, {}, self.store_api)
         location = image.locations[0]
-        self.assertEquals(image.status, 'active')
+        self.assertEqual(image.status, 'active')
         self.store_api.get_from_backend({}, location['url'])
         image.delete()
-        self.assertEquals(image.status, 'deleted')
+        self.assertEqual(image.status, 'deleted')
         self.assertRaises(exception.NotFound,
                           self.store_api.get_from_backend, {}, location['url'])
 
-    def test_image_delayed_delete(self):
-        self.config(delayed_delete=True)
-        image = glance.store.ImageProxy(self.image_stub, {}, self.store_api)
-        self.assertEquals(image.status, 'active')
-        image.delete()
-        self.assertEquals(image.status, 'pending_delete')
-        self.store_api.get_from_backend({}, image.locations[0]['url'])
-
     def test_image_get_data(self):
         image = glance.store.ImageProxy(self.image_stub, {}, self.store_api)
-        self.assertEquals(image.get_data(), 'XXX')
+        self.assertEqual(image.get_data(), 'XXX')
 
     def test_image_get_data_from_second_location(self):
         def fake_get_from_backend(self, context, location):
@@ -115,23 +109,23 @@ class TestStoreImage(utils.BaseTestCase):
                 return self.data[location]
 
         image1 = glance.store.ImageProxy(self.image_stub, {}, self.store_api)
-        self.assertEquals(image1.get_data(), 'XXX')
+        self.assertEqual(image1.get_data(), 'XXX')
         # Multiple location support
         context = glance.context.RequestContext(user=USER1)
         (image2, image_stub2) = self._add_image(context, UUID2, 'ZZZ', 3)
         location_data = image2.locations[0]
         image1.locations.append(location_data)
-        self.assertEquals(len(image1.locations), 2)
-        self.assertEquals(location_data['url'], UUID2)
+        self.assertEqual(len(image1.locations), 2)
+        self.assertEqual(location_data['url'], UUID2)
 
         self.stubs.Set(unit_test_utils.FakeStoreAPI, 'get_from_backend',
                        fake_get_from_backend)
         # This time, image1.get_data() returns the data wrapped in a
         # LimitingReader|CooperativeReader pipeline, so peeking under
         # the hood of those objects to get at the underlying string.
-        self.assertEquals(image1.get_data().data.fd, 'ZZZ')
+        self.assertEqual(image1.get_data().data.fd, 'ZZZ')
         image1.locations.pop(0)
-        self.assertEquals(len(image1.locations), 1)
+        self.assertEqual(len(image1.locations), 1)
         image2.delete()
 
     def test_image_set_data(self):
@@ -139,11 +133,11 @@ class TestStoreImage(utils.BaseTestCase):
         image_stub = ImageStub(UUID2, status='queued', locations=[])
         image = glance.store.ImageProxy(image_stub, context, self.store_api)
         image.set_data('YYYY', 4)
-        self.assertEquals(image.size, 4)
+        self.assertEqual(image.size, 4)
         #NOTE(markwash): FakeStore returns image_id for location
-        self.assertEquals(image.locations[0]['url'], UUID2)
-        self.assertEquals(image.checksum, 'Z')
-        self.assertEquals(image.status, 'active')
+        self.assertEqual(image.locations[0]['url'], UUID2)
+        self.assertEqual(image.checksum, 'Z')
+        self.assertEqual(image.status, 'active')
 
     def test_image_set_data_location_metadata(self):
         context = glance.context.RequestContext(user=USER1)
@@ -152,14 +146,14 @@ class TestStoreImage(utils.BaseTestCase):
         store_api = unit_test_utils.FakeStoreAPI(store_metadata=loc_meta)
         image = glance.store.ImageProxy(image_stub, context, store_api)
         image.set_data('YYYY', 4)
-        self.assertEquals(image.size, 4)
+        self.assertEqual(image.size, 4)
         location_data = image.locations[0]
-        self.assertEquals(location_data['url'], UUID2)
-        self.assertEquals(location_data['metadata'], loc_meta)
-        self.assertEquals(image.checksum, 'Z')
-        self.assertEquals(image.status, 'active')
+        self.assertEqual(location_data['url'], UUID2)
+        self.assertEqual(location_data['metadata'], loc_meta)
+        self.assertEqual(image.checksum, 'Z')
+        self.assertEqual(image.status, 'active')
         image.delete()
-        self.assertEquals(image.status, 'deleted')
+        self.assertEqual(image.status, 'deleted')
         self.assertRaises(exception.NotFound,
                           self.store_api.get_from_backend, {},
                           image.locations[0]['url'])
@@ -169,13 +163,13 @@ class TestStoreImage(utils.BaseTestCase):
         image_stub = ImageStub(UUID2, status='queued', locations=[])
         image = glance.store.ImageProxy(image_stub, context, self.store_api)
         image.set_data('YYYY', None)
-        self.assertEquals(image.size, 4)
+        self.assertEqual(image.size, 4)
         #NOTE(markwash): FakeStore returns image_id for location
-        self.assertEquals(image.locations[0]['url'], UUID2)
-        self.assertEquals(image.checksum, 'Z')
-        self.assertEquals(image.status, 'active')
+        self.assertEqual(image.locations[0]['url'], UUID2)
+        self.assertEqual(image.checksum, 'Z')
+        self.assertEqual(image.status, 'active')
         image.delete()
-        self.assertEquals(image.status, 'deleted')
+        self.assertEqual(image.status, 'deleted')
         self.assertRaises(exception.NotFound,
                           self.store_api.get_from_backend, {},
                           image.locations[0]['url'])
@@ -185,11 +179,11 @@ class TestStoreImage(utils.BaseTestCase):
         image = glance.store.ImageProxy(image_stub,
                                         context, self.store_api)
         image.set_data(data, len)
-        self.assertEquals(image.size, len)
+        self.assertEqual(image.size, len)
         #NOTE(markwash): FakeStore returns image_id for location
         location = {'url': image_id, 'metadata': {}}
-        self.assertEquals(image.locations, [location])
-        self.assertEquals(image_stub.locations, [location])
+        self.assertEqual(image.locations, [location])
+        self.assertEqual(image_stub.locations, [location])
         self.assertEqual(image.status, 'active')
         return (image, image_stub)
 
@@ -246,8 +240,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         image1.locations.append(location3)
 
-        self.assertEquals(image_stub1.locations, [location2, location3])
-        self.assertEquals(image1.locations, [location2, location3])
+        self.assertEqual(image_stub1.locations, [location2, location3])
+        self.assertEqual(image1.locations, [location2, location3])
 
         image1.delete()
 
@@ -270,13 +264,13 @@ class TestStoreImage(utils.BaseTestCase):
 
         image1.locations.append(location3)
 
-        self.assertEquals(image_stub1.locations, [location2, location3])
-        self.assertEquals(image1.locations, [location2, location3])
+        self.assertEqual(image_stub1.locations, [location2, location3])
+        self.assertEqual(image1.locations, [location2, location3])
 
         image1.locations.pop()
 
-        self.assertEquals(image_stub1.locations, [location2])
-        self.assertEquals(image1.locations, [location2])
+        self.assertEqual(image_stub1.locations, [location2])
+        self.assertEqual(image1.locations, [location2])
 
         image1.delete()
 
@@ -335,8 +329,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         image1.locations.extend([location3])
 
-        self.assertEquals(image_stub1.locations, [location2, location3])
-        self.assertEquals(image1.locations, [location2, location3])
+        self.assertEqual(image_stub1.locations, [location2, location3])
+        self.assertEqual(image1.locations, [location2, location3])
 
         image1.delete()
 
@@ -361,8 +355,8 @@ class TestStoreImage(utils.BaseTestCase):
         image1.locations.extend([location3])
         image1.locations.remove(location2)
 
-        self.assertEquals(image_stub1.locations, [location3])
-        self.assertEquals(image1.locations, [location3])
+        self.assertEqual(image_stub1.locations, [location3])
+        self.assertEqual(image1.locations, [location3])
         self.assertRaises(ValueError,
                           image1.locations.remove, location_bad)
 
@@ -381,7 +375,7 @@ class TestStoreImage(utils.BaseTestCase):
 
         del image1.locations[0]
 
-        self.assertEquals(image_stub1.locations, [])
+        self.assertEqual(image_stub1.locations, [])
         self.assertEqual(len(image1.locations), 0)
 
         self.assertEqual(len(self.store_api.data.keys()), 2)
@@ -437,8 +431,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         image1.locations.insert(0, location3)
 
-        self.assertEquals(image_stub1.locations, [location3, location2])
-        self.assertEquals(image1.locations, [location3, location2])
+        self.assertEqual(image_stub1.locations, [location3, location2])
+        self.assertEqual(image1.locations, [location3, location2])
 
         image1.delete()
 
@@ -462,7 +456,7 @@ class TestStoreImage(utils.BaseTestCase):
         image1.locations.insert(0, location3)
         del image1.locations[0:100]
 
-        self.assertEquals(image_stub1.locations, [])
+        self.assertEqual(image_stub1.locations, [])
         self.assertEqual(len(image1.locations), 0)
         self.assertRaises(exception.BadStoreUri,
                           image1.locations.insert, 0, location2)
@@ -487,8 +481,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         self.assertRaises(exception.BadStoreUri,
                           image1.locations.__iadd__, [location_bad])
-        self.assertEquals(image_stub1.locations, [])
-        self.assertEquals(image1.locations, [])
+        self.assertEqual(image_stub1.locations, [])
+        self.assertEqual(image1.locations, [])
 
         image1.delete()
 
@@ -508,8 +502,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         self.assertRaises(glance.store.BackendException,
                           image2.locations.__iadd__, [location_bad])
-        self.assertEquals(image_stub2.locations, [])
-        self.assertEquals(image2.locations, [])
+        self.assertEqual(image_stub2.locations, [])
+        self.assertEqual(image2.locations, [])
 
         image1.delete()
         image2.delete()
@@ -533,8 +527,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         image3.locations += [location2, location3]
 
-        self.assertEquals(image_stub3.locations, [location2, location3])
-        self.assertEquals(image3.locations, [location2, location3])
+        self.assertEqual(image_stub3.locations, [location2, location3])
+        self.assertEqual(image3.locations, [location2, location3])
 
         image3.delete()
 
@@ -644,8 +638,8 @@ class TestStoreImage(utils.BaseTestCase):
 
         image_stub3.locations.reverse()
 
-        self.assertEquals(image_stub3.locations, [location3, location2])
-        self.assertEquals(image3.locations, [location3, location2])
+        self.assertEqual(image_stub3.locations, [location3, location2])
+        self.assertEqual(image3.locations, [location3, location2])
 
         image3.delete()
 
@@ -698,8 +692,8 @@ class TestStoreImageRepo(utils.BaseTestCase):
         self.assertIn('glue', self.store_api.acls)
         acls = self.store_api.acls['glue']
         self.assertFalse(acls['public'])
-        self.assertEquals(acls['write'], [])
-        self.assertEquals(acls['read'], [TENANT1, TENANT2])
+        self.assertEqual(acls['write'], [])
+        self.assertEqual(acls['read'], [TENANT1, TENANT2])
 
     def test_save_fetches_members_if_private(self):
         self.image_stub.locations = [{'url': 'glue', 'metadata': {}}]
@@ -708,57 +702,57 @@ class TestStoreImageRepo(utils.BaseTestCase):
         self.assertIn('glue', self.store_api.acls)
         acls = self.store_api.acls['glue']
         self.assertFalse(acls['public'])
-        self.assertEquals(acls['write'], [])
-        self.assertEquals(acls['read'], [TENANT1, TENANT2])
+        self.assertEqual(acls['write'], [])
+        self.assertEqual(acls['read'], [TENANT1, TENANT2])
 
     def test_member_addition_updates_acls(self):
         self.image_stub.locations = [{'url': 'glug', 'metadata': {}}]
         self.image_stub.visibility = 'private'
         member_repo = self.image.get_member_repo()
         membership = glance.domain.ImageMembership(
-                UUID1, TENANT3, None, None, status='accepted')
+            UUID1, TENANT3, None, None, status='accepted')
         member_repo.add(membership)
         self.assertIn('glug', self.store_api.acls)
         acls = self.store_api.acls['glug']
         self.assertFalse(acls['public'])
-        self.assertEquals(acls['write'], [])
-        self.assertEquals(acls['read'], [TENANT1, TENANT2, TENANT3])
+        self.assertEqual(acls['write'], [])
+        self.assertEqual(acls['read'], [TENANT1, TENANT2, TENANT3])
 
     def test_member_removal_updates_acls(self):
         self.image_stub.locations = [{'url': 'glug', 'metadata': {}}]
         self.image_stub.visibility = 'private'
         member_repo = self.image.get_member_repo()
         membership = glance.domain.ImageMembership(
-                UUID1, TENANT1, None, None, status='accepted')
+            UUID1, TENANT1, None, None, status='accepted')
         member_repo.remove(membership)
         self.assertIn('glug', self.store_api.acls)
         acls = self.store_api.acls['glug']
         self.assertFalse(acls['public'])
-        self.assertEquals(acls['write'], [])
-        self.assertEquals(acls['read'], [TENANT2])
+        self.assertEqual(acls['write'], [])
+        self.assertEqual(acls['read'], [TENANT2])
 
 
-class TestImageFactory(utils.BaseTestCase):
+class TestImageFactory(unit_test_base.StoreClearingUnitTest):
 
     def setUp(self):
         super(TestImageFactory, self).setUp()
         self.image_factory = glance.store.ImageFactoryProxy(
-                                ImageFactoryStub(),
-                                glance.context.RequestContext(user=USER1),
-                                unit_test_utils.FakeStoreAPI())
+            ImageFactoryStub(),
+            glance.context.RequestContext(user=USER1),
+            unit_test_utils.FakeStoreAPI())
 
     def test_new_image(self):
         image = self.image_factory.new_image()
         self.assertTrue(image.image_id is None)
         self.assertTrue(image.status is None)
         self.assertEqual(image.visibility, 'private')
-        self.assertEquals(image.locations, [])
+        self.assertEqual(image.locations, [])
 
     def test_new_image_with_location(self):
         locations = [{'url': '%s/%s' % (BASE_URI, UUID1),
                       'metadata': {}}]
         image = self.image_factory.new_image(locations=locations)
-        self.assertEquals(image.locations, locations)
+        self.assertEqual(image.locations, locations)
         location_bad = {'url': 'unknown://location', 'metadata': {}}
         self.assertRaises(exception.BadStoreUri,
                           self.image_factory.new_image,
@@ -838,6 +832,7 @@ class TestStoreAddToBackend(utils.BaseTestCase):
         store.add(self.image_id, mox.IgnoreArg(), self.size).AndReturn(
             (self.location, self.size, self.checksum, in_metadata))
         store.__str__ = lambda: "hello"
+        store.__unicode__ = lambda: "hello"
 
         self.mox.ReplayAll()
 
@@ -913,6 +908,7 @@ class TestStoreAddToBackend(utils.BaseTestCase):
         store.add(self.image_id, mox.IgnoreArg(), self.size).AndReturn(
             (self.location, self.size, self.checksum, []))
         store.__str__ = lambda: "hello"
+        store.__unicode__ = lambda: "hello"
 
         self.mox.ReplayAll()
 
