@@ -1,10 +1,8 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
-# Copyright 2011 OpenStack, LLC
+# Copyright 2011 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this swift except in compliance with the License. You may obtain
+#    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
 #
 #         http://www.apache.org/licenses/LICENSE-2.0
@@ -19,29 +17,32 @@
 
 import hashlib
 import httplib
-import StringIO
+import mock
 import tempfile
-import urllib
+import uuid
 
 from oslo.config import cfg
+import six
+import six.moves.urllib.parse as urlparse
 import stubout
 import swiftclient
 
 import glance.common.auth
 from glance.common import exception
-from glance.openstack.common import uuidutils
+from glance.openstack.common import units
+
 from glance.store import BackendException
 from glance.store.location import get_location_from_uri
-import glance.store.swift
+from glance.store.swift import swift_retry_iter
 from glance.tests.unit import base
 
 CONF = cfg.CONF
 
-FAKE_UUID = uuidutils.generate_uuid
+FAKE_UUID = lambda: str(uuid.uuid4())
 
 Store = glance.store.swift.Store
-FIVE_KB = (5 * 1024)
-FIVE_GB = (5 * 1024 * 1024 * 1024)
+FIVE_KB = 5 * units.Ki
+FIVE_GB = 5 * units.Gi
 MAX_SWIFT_OBJECT_SIZE = FIVE_GB
 SWIFT_PUT_OBJECT_CALLS = 0
 SWIFT_CONF = {'verbose': True,
@@ -51,7 +52,8 @@ SWIFT_CONF = {'verbose': True,
               'swift_store_user': 'user',
               'swift_store_key': 'key',
               'swift_store_auth_address': 'localhost:8080',
-              'swift_store_container': 'glance'}
+              'swift_store_container': 'glance',
+              'swift_store_retry_get_count': 1}
 
 
 # We stub out as little as possible to ensure that the code paths
@@ -67,7 +69,7 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
         }
     }
     fixture_objects = {'glance/%s' % FAKE_UUID:
-                       StringIO.StringIO("*" * FIVE_KB)}
+                       six.StringIO("*" * FIVE_KB)}
 
     def fake_head_container(url, token, container, **kwargs):
         if container not in fixture_containers:
@@ -88,7 +90,7 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
         # Large object manifest...
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS += 1
-        CHUNKSIZE = 64 * 1024
+        CHUNKSIZE = 64 * units.Ki
         fixture_key = "%s/%s" % (container, name)
         if fixture_key not in fixture_headers:
             if kwargs.get('headers'):
@@ -97,7 +99,7 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
                                                 'etag': etag}
                 return etag
             if hasattr(contents, 'read'):
-                fixture_object = StringIO.StringIO()
+                fixture_object = six.StringIO()
                 chunk = contents.read(CHUNKSIZE)
                 checksum = hashlib.md5()
                 while chunk:
@@ -106,14 +108,14 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
                     chunk = contents.read(CHUNKSIZE)
                 etag = checksum.hexdigest()
             else:
-                fixture_object = StringIO.StringIO(contents)
+                fixture_object = six.StringIO(contents)
                 etag = hashlib.md5(fixture_object.getvalue()).hexdigest()
             read_len = fixture_object.len
             if read_len > MAX_SWIFT_OBJECT_SIZE:
                 msg = ('Image size:%d exceeds Swift max:%d' %
                        (read_len, MAX_SWIFT_OBJECT_SIZE))
                 raise swiftclient.ClientException(
-                        msg, http_status=httplib.REQUEST_ENTITY_TOO_LARGE)
+                    msg, http_status=httplib.REQUEST_ENTITY_TOO_LARGE)
             fixture_objects[fixture_key] = fixture_object
             fixture_headers[fixture_key] = {
                 'content-length': read_len,
@@ -133,6 +135,13 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
             raise swiftclient.ClientException(msg,
                                               http_status=httplib.NOT_FOUND)
 
+        byte_range = None
+        headers = kwargs.get('headers', dict())
+        if headers is not None:
+            headers = dict((k.lower(), v) for k, v in headers.iteritems())
+            if 'range' in headers:
+                byte_range = headers.get('range')
+
         fixture = fixture_headers[fixture_key]
         if 'manifest' in fixture:
             # Large object manifest... we return a file containing
@@ -140,13 +149,19 @@ def stub_out_swiftclient(stubs, swift_store_auth_version):
             chunk_keys = sorted([k for k in fixture_headers.keys()
                                  if k.startswith(fixture_key) and
                                  k != fixture_key])
-            result = StringIO.StringIO()
+            result = six.StringIO()
             for key in chunk_keys:
                 result.write(fixture_objects[key].getvalue())
-            return fixture_headers[fixture_key], result
-
         else:
-            return fixture_headers[fixture_key], fixture_objects[fixture_key]
+            result = fixture_objects[fixture_key]
+
+        if byte_range is not None:
+            start = int(byte_range.split('=')[1].strip('-'))
+            result = six.StringIO(result.getvalue()[start:])
+            fixture_headers[fixture_key]['content-length'] = len(
+                result.getvalue())
+
+        return fixture_headers[fixture_key], result
 
     def fake_head_object(url, token, container, name, **kwargs):
         # HEAD returns the list of headers for an object
@@ -207,7 +222,7 @@ class SwiftTests(object):
 
     @property
     def swift_store_user(self):
-        return urllib.quote(CONF.swift_store_user)
+        return urlparse.quote(CONF.swift_store_user)
 
     def test_get_size(self):
         """
@@ -244,6 +259,29 @@ class SwiftTests(object):
             data += chunk
         self.assertEqual(expected_data, data)
 
+    def test_get_with_retry(self):
+        """
+        Test a retrieval where Swift does not get the full image in a single
+        request.
+        """
+        uri = "swift://%s:key@auth_address/glance/%s" % (
+            self.swift_store_user, FAKE_UUID)
+        loc = get_location_from_uri(uri)
+        (image_swift, image_size) = self.store.get(loc)
+        resp_full = ''.join([chunk for chunk in image_swift.wrapped])
+        resp_half = resp_full[:len(resp_full) / 2]
+        image_swift.wrapped = swift_retry_iter(resp_half, image_size,
+                                               self.store,
+                                               loc.store_location)
+        self.assertEqual(image_size, 5120)
+
+        expected_data = "*" * FIVE_KB
+        data = ""
+
+        for chunk in image_swift:
+            data += chunk
+        self.assertEqual(expected_data, data)
+
     def test_get_with_http_auth(self):
         """
         Test a retrieval from Swift with an HTTP authurl. This is
@@ -269,7 +307,7 @@ class SwiftTests(object):
         raises an error
         """
         loc = get_location_from_uri("swift://%s:key@authurl/glance/noexist" % (
-                    self.swift_store_user))
+            self.swift_store_user))
         self.assertRaises(exception.NotFound,
                           self.store.get,
                           loc)
@@ -279,32 +317,32 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = "*" * expected_swift_size
         expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
-        expected_image_id = uuidutils.generate_uuid()
+        expected_image_id = str(uuid.uuid4())
         loc = 'swift+https://%s:key@localhost:8080/glance/%s'
         expected_location = loc % (self.swift_store_user,
                                    expected_image_id)
-        image_swift = StringIO.StringIO(expected_swift_contents)
+        image_swift = six.StringIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
 
-        location, size, checksum = self.store.add(expected_image_id,
-                                                  image_swift,
-                                                  expected_swift_size)
+        location, size, checksum, _ = self.store.add(expected_image_id,
+                                                     image_swift,
+                                                     expected_swift_size)
 
-        self.assertEquals(expected_location, location)
-        self.assertEquals(expected_swift_size, size)
-        self.assertEquals(expected_checksum, checksum)
+        self.assertEqual(expected_location, location)
+        self.assertEqual(expected_swift_size, size)
+        self.assertEqual(expected_checksum, checksum)
         # Expecting a single object to be created on Swift i.e. no chunking.
-        self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 1)
+        self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 1)
 
         loc = get_location_from_uri(expected_location)
         (new_image_swift, new_image_size) = self.store.get(loc)
-        new_image_contents = new_image_swift.getvalue()
+        new_image_contents = ''.join([chunk for chunk in new_image_swift])
         new_image_swift_size = len(new_image_swift)
 
-        self.assertEquals(expected_swift_contents, new_image_contents)
-        self.assertEquals(expected_swift_size, new_image_swift_size)
+        self.assertEqual(expected_swift_contents, new_image_contents)
+        self.assertEqual(expected_swift_size, new_image_swift_size)
 
     def test_add_auth_url_variations(self):
         """
@@ -332,7 +370,7 @@ class SwiftTests(object):
         }
 
         for variation, expected_location in variations.items():
-            image_id = uuidutils.generate_uuid()
+            image_id = str(uuid.uuid4())
             expected_location = expected_location % (
                 self.swift_store_user, image_id)
             expected_swift_size = FIVE_KB
@@ -340,28 +378,28 @@ class SwiftTests(object):
             expected_checksum = \
                 hashlib.md5(expected_swift_contents).hexdigest()
 
-            image_swift = StringIO.StringIO(expected_swift_contents)
+            image_swift = six.StringIO(expected_swift_contents)
 
             global SWIFT_PUT_OBJECT_CALLS
             SWIFT_PUT_OBJECT_CALLS = 0
 
             self.config(swift_store_auth_address=variation)
             self.store = Store()
-            location, size, checksum = self.store.add(image_id, image_swift,
-                                                      expected_swift_size)
+            location, size, checksum, _ = self.store.add(image_id, image_swift,
+                                                         expected_swift_size)
 
-            self.assertEquals(expected_location, location)
-            self.assertEquals(expected_swift_size, size)
-            self.assertEquals(expected_checksum, checksum)
-            self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 1)
+            self.assertEqual(expected_location, location)
+            self.assertEqual(expected_swift_size, size)
+            self.assertEqual(expected_checksum, checksum)
+            self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 1)
 
             loc = get_location_from_uri(expected_location)
             (new_image_swift, new_image_size) = self.store.get(loc)
-            new_image_contents = new_image_swift.getvalue()
+            new_image_contents = ''.join([chunk for chunk in new_image_swift])
             new_image_swift_size = len(new_image_swift)
 
-            self.assertEquals(expected_swift_contents, new_image_contents)
-            self.assertEquals(expected_swift_size, new_image_swift_size)
+            self.assertEqual(expected_swift_contents, new_image_contents)
+            self.assertEqual(expected_swift_size, new_image_swift_size)
 
     def test_add_no_container_no_create(self):
         """
@@ -372,7 +410,7 @@ class SwiftTests(object):
                     swift_store_container='noexist')
         self.store = Store()
 
-        image_swift = StringIO.StringIO("nevergonnamakeit")
+        image_swift = six.StringIO("nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -382,13 +420,13 @@ class SwiftTests(object):
         # simply used self.assertRaises here
         exception_caught = False
         try:
-            self.store.add(uuidutils.generate_uuid(), image_swift, 0)
-        except BackendException, e:
+            self.store.add(str(uuid.uuid4()), image_swift, 0)
+        except BackendException as e:
             exception_caught = True
             self.assertTrue("container noexist does not exist "
-                            "in Swift" in str(e))
+                            "in Swift" in six.text_type(e))
         self.assertTrue(exception_caught)
-        self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 0)
+        self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 0)
 
     def test_add_no_container_and_create(self):
         """
@@ -398,11 +436,11 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = "*" * expected_swift_size
         expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
-        expected_image_id = uuidutils.generate_uuid()
+        expected_image_id = str(uuid.uuid4())
         loc = 'swift+https://%s:key@localhost:8080/noexist/%s'
         expected_location = loc % (self.swift_store_user,
                                    expected_image_id)
-        image_swift = StringIO.StringIO(expected_swift_contents)
+        image_swift = six.StringIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -410,22 +448,22 @@ class SwiftTests(object):
         self.config(swift_store_create_container_on_put=True,
                     swift_store_container='noexist')
         self.store = Store()
-        location, size, checksum = self.store.add(expected_image_id,
-                                                  image_swift,
-                                                  expected_swift_size)
+        location, size, checksum, _ = self.store.add(expected_image_id,
+                                                     image_swift,
+                                                     expected_swift_size)
 
-        self.assertEquals(expected_location, location)
-        self.assertEquals(expected_swift_size, size)
-        self.assertEquals(expected_checksum, checksum)
-        self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 1)
+        self.assertEqual(expected_location, location)
+        self.assertEqual(expected_swift_size, size)
+        self.assertEqual(expected_checksum, checksum)
+        self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 1)
 
         loc = get_location_from_uri(expected_location)
         (new_image_swift, new_image_size) = self.store.get(loc)
-        new_image_contents = new_image_swift.getvalue()
+        new_image_contents = ''.join([chunk for chunk in new_image_swift])
         new_image_swift_size = len(new_image_swift)
 
-        self.assertEquals(expected_swift_contents, new_image_contents)
-        self.assertEquals(expected_swift_size, new_image_swift_size)
+        self.assertEqual(expected_swift_contents, new_image_contents)
+        self.assertEqual(expected_swift_size, new_image_swift_size)
 
     def test_add_large_object(self):
         """
@@ -437,11 +475,11 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = "*" * expected_swift_size
         expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
-        expected_image_id = uuidutils.generate_uuid()
+        expected_image_id = str(uuid.uuid4())
         loc = 'swift+https://%s:key@localhost:8080/glance/%s'
         expected_location = loc % (self.swift_store_user,
                                    expected_image_id)
-        image_swift = StringIO.StringIO(expected_swift_contents)
+        image_swift = six.StringIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -453,27 +491,27 @@ class SwiftTests(object):
         try:
             self.store.large_object_size = 1024
             self.store.large_object_chunk_size = 1024
-            location, size, checksum = self.store.add(expected_image_id,
-                                                      image_swift,
-                                                      expected_swift_size)
+            location, size, checksum, _ = self.store.add(expected_image_id,
+                                                         image_swift,
+                                                         expected_swift_size)
         finally:
             self.store.large_object_chunk_size = orig_temp_size
             self.store.large_object_size = orig_max_size
 
-        self.assertEquals(expected_location, location)
-        self.assertEquals(expected_swift_size, size)
-        self.assertEquals(expected_checksum, checksum)
+        self.assertEqual(expected_location, location)
+        self.assertEqual(expected_swift_size, size)
+        self.assertEqual(expected_checksum, checksum)
         # Expecting 6 objects to be created on Swift -- 5 chunks and 1
         # manifest.
-        self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 6)
+        self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 6)
 
         loc = get_location_from_uri(expected_location)
         (new_image_swift, new_image_size) = self.store.get(loc)
-        new_image_contents = new_image_swift.getvalue()
-        new_image_swift_size = len(new_image_swift)
+        new_image_contents = ''.join([chunk for chunk in new_image_swift])
+        new_image_swift_size = len(new_image_contents)
 
-        self.assertEquals(expected_swift_contents, new_image_contents)
-        self.assertEquals(expected_swift_size, new_image_swift_size)
+        self.assertEqual(expected_swift_contents, new_image_contents)
+        self.assertEqual(expected_swift_size, new_image_swift_size)
 
     def test_add_large_object_zero_size(self):
         """
@@ -490,11 +528,11 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = "*" * expected_swift_size
         expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
-        expected_image_id = uuidutils.generate_uuid()
+        expected_image_id = str(uuid.uuid4())
         loc = 'swift+https://%s:key@localhost:8080/glance/%s'
         expected_location = loc % (self.swift_store_user,
                                    expected_image_id)
-        image_swift = StringIO.StringIO(expected_swift_contents)
+        image_swift = six.StringIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -511,40 +549,65 @@ class SwiftTests(object):
             MAX_SWIFT_OBJECT_SIZE = 1024
             self.store.large_object_size = 1024
             self.store.large_object_chunk_size = 1024
-            location, size, checksum = self.store.add(expected_image_id,
-                                                      image_swift, 0)
+            location, size, checksum, _ = self.store.add(expected_image_id,
+                                                         image_swift, 0)
         finally:
             self.store.large_object_chunk_size = orig_temp_size
             self.store.large_object_size = orig_max_size
             MAX_SWIFT_OBJECT_SIZE = orig_max_swift_object_size
 
-        self.assertEquals(expected_location, location)
-        self.assertEquals(expected_swift_size, size)
-        self.assertEquals(expected_checksum, checksum)
+        self.assertEqual(expected_location, location)
+        self.assertEqual(expected_swift_size, size)
+        self.assertEqual(expected_checksum, checksum)
         # Expecting 7 calls to put_object -- 5 chunks, a zero chunk which is
         # then deleted, and the manifest.  Note the difference with above
         # where the image_size is specified in advance (there's no zero chunk
         # in that case).
-        self.assertEquals(SWIFT_PUT_OBJECT_CALLS, 7)
+        self.assertEqual(SWIFT_PUT_OBJECT_CALLS, 7)
 
         loc = get_location_from_uri(expected_location)
         (new_image_swift, new_image_size) = self.store.get(loc)
-        new_image_contents = new_image_swift.getvalue()
-        new_image_swift_size = len(new_image_swift)
+        new_image_contents = ''.join([chunk for chunk in new_image_swift])
+        new_image_swift_size = len(new_image_contents)
 
-        self.assertEquals(expected_swift_contents, new_image_contents)
-        self.assertEquals(expected_swift_size, new_image_swift_size)
+        self.assertEqual(expected_swift_contents, new_image_contents)
+        self.assertEqual(expected_swift_size, new_image_swift_size)
 
     def test_add_already_existing(self):
         """
         Tests that adding an image with an existing identifier
         raises an appropriate exception
         """
-        image_swift = StringIO.StringIO("nevergonnamakeit")
+        image_swift = six.StringIO("nevergonnamakeit")
         self.assertRaises(exception.Duplicate,
                           self.store.add,
                           FAKE_UUID, image_swift, 0)
 
+    def test_add_saves_and_reraises_and_not_uses_wildcard_raise(self):
+        image_id = str(uuid.uuid4())
+        swift_size = self.store.large_object_size = 1024
+        swift_contents = "*" * swift_size
+        connection = mock.Mock()
+
+        def fake_delete_chunk(connection,
+                              container,
+                              chunks):
+            try:
+                raise Exception()
+            except Exception:
+                pass
+
+        image_swift = six.StringIO(swift_contents)
+        connection.put_object.side_effect = exception.ClientConnectionError
+        self.store._delete_stale_chunks = fake_delete_chunk
+
+        self.assertRaises(exception.ClientConnectionError,
+                          self.store.add,
+                          image_id,
+                          image_swift,
+                          swift_size,
+                          connection)
+
     def _option_required(self, key):
         conf = self.getConfig()
         conf[key] = None
@@ -553,7 +616,7 @@ class SwiftTests(object):
             self.config(**conf)
             self.store = Store()
             return self.store.add == self.store.add_disabled
-        except:
+        except Exception:
             return False
         return False
 
@@ -592,7 +655,7 @@ class SwiftTests(object):
         raises an error
         """
         loc = get_location_from_uri("swift://%s:key@authurl/glance/noexist" % (
-                self.swift_store_user))
+            self.swift_store_user))
         self.assertRaises(exception.NotFound, self.store.delete, loc)
 
     def test_read_acl_public(self):
@@ -624,9 +687,9 @@ class SwiftTests(object):
         container_headers = swiftclient.client.head_container('x', 'y',
                                                               'glance')
         self.assertEqual(container_headers['X-Container-Read'],
-                         ','.join(read_tenants))
+                         'matt:*,mark:*')
 
-    def test_read_write_public(self):
+    def test_write_acls(self):
         """
         Test that we can set write acl for tenants.
         """
@@ -640,7 +703,7 @@ class SwiftTests(object):
         container_headers = swiftclient.client.head_container('x', 'y',
                                                               'glance')
         self.assertEqual(container_headers['X-Container-Write'],
-                         ','.join(read_tenants))
+                         'frank:*,jim:*')
 
 
 class TestStoreAuthV1(base.StoreClearingUnitTest, SwiftTests):
@@ -691,7 +754,8 @@ class TestStoreAuthV2(TestStoreAuthV1):
 class FakeConnection(object):
     def __init__(self, authurl, user, key, retries=5, preauthurl=None,
                  preauthtoken=None, snet=False, starting_backoff=1,
-                 tenant_name=None, os_options={}, auth_version="1"):
+                 tenant_name=None, os_options={}, auth_version="1",
+                 insecure=False, ssl_compression=True):
         self.authurl = authurl
         self.user = user
         self.key = key
@@ -701,6 +765,7 @@ class FakeConnection(object):
         self.tenant_name = tenant_name
         self.os_options = os_options
         self.auth_version = auth_version
+        self.insecure = insecure
 
 
 class TestSingleTenantStoreConnections(base.IsolatedUnitTest):
@@ -723,9 +788,10 @@ class TestSingleTenantStoreConnections(base.IsolatedUnitTest):
         self.assertEqual(connection.user, 'user')
         self.assertEqual(connection.tenant_name, 'tenant')
         self.assertEqual(connection.key, 'abcdefg')
-        self.assertEqual(connection.snet, False)
-        self.assertEqual(connection.preauthurl, None)
-        self.assertEqual(connection.preauthtoken, None)
+        self.assertFalse(connection.snet)
+        self.assertIsNone(connection.preauthurl)
+        self.assertIsNone(connection.preauthtoken)
+        self.assertFalse(connection.insecure)
         self.assertEqual(connection.os_options,
                          {'service_type': 'object-store',
                           'endpoint_type': 'publicURL'})
@@ -735,6 +801,12 @@ class TestSingleTenantStoreConnections(base.IsolatedUnitTest):
         connection = self.store.get_connection(self.location)
         self.assertEqual(connection.authurl, 'https://example.com/v2/')
 
+    def test_connection_insecure(self):
+        self.config(swift_store_auth_insecure=True)
+        self.store.configure()
+        connection = self.store.get_connection(self.location)
+        self.assertTrue(connection.insecure)
+
     def test_connection_with_auth_v1(self):
         self.config(swift_store_auth_version='1')
         self.store.configure()
@@ -742,7 +814,7 @@ class TestSingleTenantStoreConnections(base.IsolatedUnitTest):
         connection = self.store.get_connection(self.location)
         self.assertEqual(connection.auth_version, '1')
         self.assertEqual(connection.user, 'auth_v1_user')
-        self.assertEqual(connection.tenant_name, None)
+        self.assertIsNone(connection.tenant_name)
 
     def test_connection_invalid_user(self):
         self.store.configure()
@@ -760,32 +832,32 @@ class TestSingleTenantStoreConnections(base.IsolatedUnitTest):
         self.config(swift_store_region='Sahara')
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEquals(connection.os_options,
-                          {'region_name': 'Sahara',
-                           'service_type': 'object-store',
-                           'endpoint_type': 'publicURL'})
+        self.assertEqual(connection.os_options,
+                         {'region_name': 'Sahara',
+                          'service_type': 'object-store',
+                          'endpoint_type': 'publicURL'})
 
     def test_connection_with_service_type(self):
         self.config(swift_store_service_type='shoe-store')
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEquals(connection.os_options,
-                          {'service_type': 'shoe-store',
-                           'endpoint_type': 'publicURL'})
+        self.assertEqual(connection.os_options,
+                         {'service_type': 'shoe-store',
+                          'endpoint_type': 'publicURL'})
 
     def test_connection_with_endpoint_type(self):
         self.config(swift_store_endpoint_type='internalURL')
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEquals(connection.os_options,
-                          {'service_type': 'object-store',
-                           'endpoint_type': 'internalURL'})
+        self.assertEqual(connection.os_options,
+                         {'service_type': 'object-store',
+                          'endpoint_type': 'internalURL'})
 
     def test_connection_with_snet(self):
         self.config(swift_enable_snet=True)
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEquals(connection.snet, True)
+        self.assertTrue(connection.snet)
 
 
 class TestMultiTenantStoreConnections(base.IsolatedUnitTest):
@@ -793,7 +865,7 @@ class TestMultiTenantStoreConnections(base.IsolatedUnitTest):
         super(TestMultiTenantStoreConnections, self).setUp()
         self.stubs.Set(swiftclient, 'Connection', FakeConnection)
         self.context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='0123')
+            user='user', tenant='tenant', auth_tok='0123')
         self.store = glance.store.swift.MultiTenantStore(self.context)
         specs = {'scheme': 'swift',
                  'auth_or_store_url': 'example.com',
@@ -804,12 +876,12 @@ class TestMultiTenantStoreConnections(base.IsolatedUnitTest):
     def test_basic_connection(self):
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEqual(connection.authurl, None)
+        self.assertIsNone(connection.authurl)
         self.assertEqual(connection.auth_version, '2')
         self.assertEqual(connection.user, 'user')
         self.assertEqual(connection.tenant_name, 'tenant')
-        self.assertEqual(connection.key, None)
-        self.assertEqual(connection.snet, False)
+        self.assertIsNone(connection.key)
+        self.assertFalse(connection.snet)
         self.assertEqual(connection.preauthurl, 'https://example.com')
         self.assertEqual(connection.preauthtoken, '0123')
         self.assertEqual(connection.os_options, {})
@@ -818,7 +890,7 @@ class TestMultiTenantStoreConnections(base.IsolatedUnitTest):
         self.config(swift_enable_snet=True)
         self.store.configure()
         connection = self.store.get_connection(self.location)
-        self.assertEquals(connection.snet, True)
+        self.assertTrue(connection.snet)
 
 
 class FakeGetEndpoint(object):
@@ -841,12 +913,12 @@ class TestCreatingLocations(base.IsolatedUnitTest):
                     swift_store_key='auth_key')
         store = glance.store.swift.SingleTenantStore()
         location = store.create_location('image-id')
-        self.assertEquals(location.scheme, 'swift+https')
-        self.assertEquals(location.swift_url, 'https://example.com/v2')
-        self.assertEquals(location.container, 'container')
-        self.assertEquals(location.obj, 'image-id')
-        self.assertEquals(location.user, 'tenant:user')
-        self.assertEquals(location.key, 'auth_key')
+        self.assertEqual(location.scheme, 'swift+https')
+        self.assertEqual(location.swift_url, 'https://example.com/v2')
+        self.assertEqual(location.container, 'container')
+        self.assertEqual(location.obj, 'image-id')
+        self.assertEqual(location.user, 'tenant:user')
+        self.assertEqual(location.key, 'auth_key')
 
     def test_single_tenant_location_http(self):
         self.config(swift_store_auth_address='http://example.com/v2',
@@ -855,66 +927,66 @@ class TestCreatingLocations(base.IsolatedUnitTest):
                     swift_store_key='auth_key')
         store = glance.store.swift.SingleTenantStore()
         location = store.create_location('image-id')
-        self.assertEquals(location.scheme, 'swift+http')
-        self.assertEquals(location.swift_url, 'http://example.com/v2')
+        self.assertEqual(location.scheme, 'swift+http')
+        self.assertEqual(location.swift_url, 'http://example.com/v2')
 
     def test_multi_tenant_location(self):
         self.config(swift_store_container='container')
         fake_get_endpoint = FakeGetEndpoint('https://some_endpoint')
         self.stubs.Set(glance.common.auth, 'get_endpoint', fake_get_endpoint)
         context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='123',
-                service_catalog={})
+            user='user', tenant='tenant', auth_tok='123',
+            service_catalog={})
         store = glance.store.swift.MultiTenantStore(context)
         location = store.create_location('image-id')
-        self.assertEquals(location.scheme, 'swift+https')
-        self.assertEquals(location.swift_url, 'https://some_endpoint')
-        self.assertEquals(location.container, 'container_image-id')
-        self.assertEquals(location.obj, 'image-id')
-        self.assertEquals(location.user, None)
-        self.assertEquals(location.key, None)
-        self.assertEquals(fake_get_endpoint.service_type, 'object-store')
+        self.assertEqual(location.scheme, 'swift+https')
+        self.assertEqual(location.swift_url, 'https://some_endpoint')
+        self.assertEqual(location.container, 'container_image-id')
+        self.assertEqual(location.obj, 'image-id')
+        self.assertIsNone(location.user)
+        self.assertIsNone(location.key)
+        self.assertEqual(fake_get_endpoint.service_type, 'object-store')
 
     def test_multi_tenant_location_http(self):
         fake_get_endpoint = FakeGetEndpoint('http://some_endpoint')
         self.stubs.Set(glance.common.auth, 'get_endpoint', fake_get_endpoint)
         context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='123',
-                service_catalog={})
+            user='user', tenant='tenant', auth_tok='123',
+            service_catalog={})
         store = glance.store.swift.MultiTenantStore(context)
         location = store.create_location('image-id')
-        self.assertEquals(location.scheme, 'swift+http')
-        self.assertEquals(location.swift_url, 'http://some_endpoint')
+        self.assertEqual(location.scheme, 'swift+http')
+        self.assertEqual(location.swift_url, 'http://some_endpoint')
 
     def test_multi_tenant_location_with_region(self):
         self.config(swift_store_region='WestCarolina')
         fake_get_endpoint = FakeGetEndpoint('https://some_endpoint')
         self.stubs.Set(glance.common.auth, 'get_endpoint', fake_get_endpoint)
         context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='123',
-                service_catalog={})
-        store = glance.store.swift.MultiTenantStore(context)
-        self.assertEquals(fake_get_endpoint.endpoint_region, 'WestCarolina')
+            user='user', tenant='tenant', auth_tok='123',
+            service_catalog={})
+        glance.store.swift.MultiTenantStore(context)
+        self.assertEqual(fake_get_endpoint.endpoint_region, 'WestCarolina')
 
     def test_multi_tenant_location_custom_service_type(self):
         self.config(swift_store_service_type='toy-store')
         fake_get_endpoint = FakeGetEndpoint('https://some_endpoint')
         self.stubs.Set(glance.common.auth, 'get_endpoint', fake_get_endpoint)
         context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='123',
-                service_catalog={})
-        store = glance.store.swift.MultiTenantStore(context)
-        self.assertEquals(fake_get_endpoint.service_type, 'toy-store')
+            user='user', tenant='tenant', auth_tok='123',
+            service_catalog={})
+        glance.store.swift.MultiTenantStore(context)
+        self.assertEqual(fake_get_endpoint.service_type, 'toy-store')
 
-    def test_multi_tenant_location_custom_service_type(self):
+    def test_multi_tenant_location_custom_endpoint_type(self):
         self.config(swift_store_endpoint_type='InternalURL')
         fake_get_endpoint = FakeGetEndpoint('https://some_endpoint')
         self.stubs.Set(glance.common.auth, 'get_endpoint', fake_get_endpoint)
         context = glance.context.RequestContext(
-                user='user', tenant='tenant', auth_tok='123',
-                service_catalog={})
-        store = glance.store.swift.MultiTenantStore(context)
-        self.assertEquals(fake_get_endpoint.endpoint_type, 'InternalURL')
+            user='user', tenant='tenant', auth_tok='123',
+            service_catalog={})
+        glance.store.swift.MultiTenantStore(context)
+        self.assertEqual(fake_get_endpoint.endpoint_type, 'InternalURL')
 
 
 class TestChunkReader(base.StoreClearingUnitTest):
@@ -927,7 +999,7 @@ class TestChunkReader(base.StoreClearingUnitTest):
         CHUNKSIZE = 100
         checksum = hashlib.md5()
         data_file = tempfile.NamedTemporaryFile()
-        data_file.write('*' * 1024)
+        data_file.write('*' * units.Ki)
         data_file.flush()
         infile = open(data_file.name, 'rb')
         bytes_read = 0
@@ -935,7 +1007,7 @@ class TestChunkReader(base.StoreClearingUnitTest):
             cr = glance.store.swift.ChunkReader(infile, checksum, CHUNKSIZE)
             chunk = cr.read(CHUNKSIZE)
             bytes_read += len(chunk)
-            if len(chunk) == 0:
+            if not chunk:
                 break
         self.assertEqual(1024, bytes_read)
         data_file.close()
