@@ -13,7 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import urllib
+
 from oslo.config import cfg
+import six.moves.urllib.parse as urlparse
 
 from glance.common import exception
 from glance.common import wsgi
@@ -39,6 +42,26 @@ USER3 = '2hss8dkl-d8jh-88yd-uhs9-879sdjsd8skd'
 BASE_URI = 'http://storeurl.com/container'
 
 
+def sort_url_by_qs_keys(url):
+    #NOTE(kragniz): this only sorts the keys of the query string of a url.
+    # For example, an input of '/v2/tasks?sort_key=id&sort_dir=asc&limit=10'
+    # returns '/v2/tasks?limit=10&sort_dir=asc&sort_key=id'. This is to prevent
+    # non-deterministic ordering of the query string causing problems with unit
+    # tests.
+
+    parsed = urlparse.urlparse(url)
+    queries = urlparse.parse_qsl(parsed.query, True)
+    sorted_query = sorted(queries, key=lambda x: x[0])
+
+    encoded_sorted_query = urllib.urlencode(sorted_query, True)
+
+    url_parts = (parsed.scheme, parsed.netloc, parsed.path,
+                 parsed.params, encoded_sorted_query,
+                 parsed.fragment)
+
+    return urlparse.urlunparse(url_parts)
+
+
 def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
                      roles=['member'], tenant=TENANT1):
     req = wsgi.Request.blank(path)
@@ -148,7 +171,10 @@ class FakeStoreAPI(object):
             if image_id in location:
                 raise exception.Duplicate()
         if not size:
-            size = len(data.fd)
+            # 'data' is a string wrapped in a LimitingReader|CooperativeReader
+            # pipeline, so peek under the hood of those objects to get at the
+            # string itself.
+            size = len(data.data.fd)
         if (current_store_size + size) > store_max_size:
             raise exception.StorageFull()
         if context.user == USER2:
@@ -162,6 +188,12 @@ class FakeStoreAPI(object):
     def check_location_metadata(self, val, key=''):
         glance.store.check_location_metadata(val)
 
+    def validate_external_location(self, uri):
+        if uri and urlparse.urlparse(uri).scheme:
+            return glance.store.validate_external_location(uri)
+        else:
+            return True
+
 
 class FakePolicyEnforcer(object):
     def __init__(self, *_args, **kwargs):
