@@ -1,4 +1,4 @@
-# Copyright 2013 OpenStack LLC.
+# Copyright 2013 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -14,12 +14,12 @@
 #    under the License.
 
 import datetime
-import json
 
 from oslo.config import cfg
 import webob
 
 import glance.api.v2.image_members
+from glance.openstack.common import jsonutils
 import glance.tests.unit.utils as unit_test_utils
 import glance.tests.utils as test_utils
 
@@ -72,6 +72,7 @@ def _db_image_member_fixture(image_id, member_id, **kwargs):
     obj = {
         'image_id': image_id,
         'member': member_id,
+        'status': 'pending',
     }
     obj.update(kwargs)
     return obj
@@ -188,6 +189,34 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.index,
                           request, image_id=UUID2)
 
+    def test_show(self):
+        request = unit_test_utils.get_fake_request(tenant=TENANT1)
+        output = self.controller.show(request, UUID2, TENANT4)
+        expected = self.image_members[0]
+        self.assertEqual(output.image_id, expected['image_id'])
+        self.assertEqual(output.member_id, expected['member'])
+        self.assertEqual(output.status, expected['status'])
+
+    def test_show_by_member(self):
+        request = unit_test_utils.get_fake_request(tenant=TENANT4)
+        output = self.controller.show(request, UUID2, TENANT4)
+        expected = self.image_members[0]
+        self.assertEqual(output.image_id, expected['image_id'])
+        self.assertEqual(output.member_id, expected['member'])
+        self.assertEqual(output.status, expected['status'])
+
+    def test_show_forbidden(self):
+        request = unit_test_utils.get_fake_request(tenant=TENANT2)
+        self.assertRaises(webob.exc.HTTPNotFound, self.controller.show,
+                          request, UUID2, TENANT4)
+
+    def test_show_not_found(self):
+        # one member should not be able to view status of another member
+        # of the same image
+        request = unit_test_utils.get_fake_request(tenant=TENANT2)
+        self.assertRaises(webob.exc.HTTPNotFound, self.controller.show,
+                          request, UUID3, TENANT4)
+
     def test_create(self):
         request = unit_test_utils.get_fake_request()
         image_id = UUID2
@@ -225,6 +254,25 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertRaises(webob.exc.HTTPConflict, self.controller.create,
                           request, image_id=image_id, member_id=member_id)
 
+    def test_create_overlimit(self):
+        self.config(image_member_quota=0)
+        request = unit_test_utils.get_fake_request()
+        image_id = UUID2
+        member_id = TENANT3
+        self.assertRaises(webob.exc.HTTPRequestEntityTooLarge,
+                          self.controller.create, request,
+                          image_id=image_id, member_id=member_id)
+
+    def test_create_unlimited(self):
+        self.config(image_member_quota=-1)
+        request = unit_test_utils.get_fake_request()
+        image_id = UUID2
+        member_id = TENANT3
+        output = self.controller.create(request, image_id=image_id,
+                                        member_id=member_id)
+        self.assertEqual(UUID2, output.image_id)
+        self.assertEqual(TENANT3, output.member_id)
+
     def test_update_done_by_member(self):
         request = unit_test_utils.get_fake_request(tenant=TENANT4)
         image_id = UUID2
@@ -257,15 +305,11 @@ class TestImageMembersController(test_utils.BaseTestCase):
 
     def test_update_done_by_owner(self):
         request = unit_test_utils.get_fake_request(tenant=TENANT1)
-        image_id = UUID2
-        member_id = TENANT4
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.update,
                           request, UUID2, TENANT4, status='accepted')
 
     def test_update_invalid_status(self):
         request = unit_test_utils.get_fake_request(tenant=TENANT4)
-        image_id = UUID2
-        member_id = TENANT4
         self.assertRaises(webob.exc.HTTPBadRequest, self.controller.update,
                           request, UUID2, TENANT4, status='accept')
 
@@ -294,7 +338,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
         self.assertEqual(res.body, '')
         self.assertEqual(res.status_code, 204)
         found_member = self.db.image_member_find(
-                request.context, image_id=image_id, member=member_id)
+            request.context, image_id=image_id, member=member_id)
         self.assertEqual(found_member, [])
 
     def test_delete_by_member(self):
@@ -355,7 +399,7 @@ class TestImageMembersController(test_utils.BaseTestCase):
         member_id = 'fake-member-id'
         image_id = UUID2
         found_member = self.db.image_member_find(
-                request.context, image_id=image_id, member=member_id)
+            request.context, image_id=image_id, member=member_id)
         self.assertEqual(found_member, [])
         self.assertRaises(webob.exc.HTTPNotFound, self.controller.delete,
                           request, image_id, member_id)
@@ -401,7 +445,25 @@ class TestImageMembersSerializer(test_utils.BaseTestCase):
         response = webob.Response(request=request)
         result = {'members': self.fixtures}
         self.serializer.index(response, result)
-        actual = json.loads(response.body)
+        actual = jsonutils.loads(response.body)
+        self.assertEqual(expected, actual)
+        self.assertEqual('application/json', response.content_type)
+
+    def test_show(self):
+        expected = {
+            'image_id': UUID2,
+            'member_id': TENANT1,
+            'status': 'accepted',
+            'created_at': ISOTIME,
+            'updated_at': ISOTIME,
+            'schema': '/v2/schemas/member',
+        }
+        request = webob.Request.blank('/v2/images/%s/members/%s'
+                                      % (UUID2, TENANT1))
+        response = webob.Response(request=request)
+        result = self.fixtures[0]
+        self.serializer.show(response, result)
+        actual = jsonutils.loads(response.body)
         self.assertEqual(expected, actual)
         self.assertEqual('application/json', response.content_type)
 
@@ -417,7 +479,7 @@ class TestImageMembersSerializer(test_utils.BaseTestCase):
         response = webob.Response(request=request)
         result = self.fixtures[0]
         self.serializer.create(response, result)
-        actual = json.loads(response.body)
+        actual = jsonutils.loads(response.body)
         self.assertEqual(expected, actual)
         self.assertEqual('application/json', response.content_type)
 
@@ -433,7 +495,7 @@ class TestImageMembersSerializer(test_utils.BaseTestCase):
         response = webob.Response(request=request)
         result = self.fixtures[0]
         self.serializer.update(response, result)
-        actual = json.loads(response.body)
+        actual = jsonutils.loads(response.body)
         self.assertEqual(expected, actual)
         self.assertEqual('application/json', response.content_type)
 
@@ -446,16 +508,14 @@ class TestImagesDeserializer(test_utils.BaseTestCase):
 
     def test_create(self):
         request = unit_test_utils.get_fake_request()
-        request.body = json.dumps({'member': TENANT1})
-        image_id = UUID1
+        request.body = jsonutils.dumps({'member': TENANT1})
         output = self.deserializer.create(request)
         expected = {'member_id': TENANT1}
         self.assertEqual(expected, output)
 
     def test_create_invalid(self):
         request = unit_test_utils.get_fake_request()
-        image_id = UUID1
-        request.body = json.dumps({'mem': TENANT1})
+        request.body = jsonutils.dumps({'mem': TENANT1})
         self.assertRaises(webob.exc.HTTPBadRequest, self.deserializer.create,
                           request)
 
@@ -466,24 +526,20 @@ class TestImagesDeserializer(test_utils.BaseTestCase):
 
     def test_create_member_empty(self):
         request = unit_test_utils.get_fake_request()
-        request.body = json.dumps({'member': ''})
+        request.body = jsonutils.dumps({'member': ''})
         self.assertRaises(webob.exc.HTTPBadRequest, self.deserializer.create,
                           request)
 
     def test_update(self):
         request = unit_test_utils.get_fake_request()
-        request.body = json.dumps({'status': 'accepted'})
-        image_id = UUID1
-        member_id = TENANT1
+        request.body = jsonutils.dumps({'status': 'accepted'})
         output = self.deserializer.update(request)
         expected = {'status': 'accepted'}
         self.assertEqual(expected, output)
 
     def test_update_invalid(self):
         request = unit_test_utils.get_fake_request()
-        image_id = UUID1
-        member_id = TENANT1
-        request.body = json.dumps({'mem': TENANT1})
+        request.body = jsonutils.dumps({'mem': TENANT1})
         self.assertRaises(webob.exc.HTTPBadRequest, self.deserializer.update,
                           request)
 
