@@ -1,4 +1,4 @@
-# Copyright 2012 OpenStack, LLC
+# Copyright 2012 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,16 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
-
 import webob
 
 import glance.api.v2.image_tags
+from glance.tests.unit import base
 import glance.tests.unit.utils as unit_test_utils
 import glance.tests.utils as test_utils
 
 
-class TestImageTagsController(test_utils.BaseTestCase):
+class TestImageTagsController(base.IsolatedUnitTest):
 
     def setUp(self):
         super(TestImageTagsController, self).setUp()
@@ -36,6 +35,13 @@ class TestImageTagsController(test_utils.BaseTestCase):
         tags = self.db.image_tag_get_all(context, unit_test_utils.UUID1)
         self.assertEqual(1, len([tag for tag in tags if tag == 'dink']))
 
+    def test_create_too_many_tags(self):
+        self.config(image_tag_quota=0)
+        request = unit_test_utils.get_fake_request()
+        self.assertRaises(webob.exc.HTTPRequestEntityTooLarge,
+                          self.controller.update,
+                          request, unit_test_utils.UUID1, 'dink')
+
     def test_create_duplicate_tag_ignored(self):
         request = unit_test_utils.get_fake_request()
         self.controller.update(request, unit_test_utils.UUID1, 'dink')
