@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Red Hat, Inc.
 # All Rights Reserved.
 #
@@ -24,6 +22,7 @@ the registry's driver tests will be added.
 import copy
 import datetime
 import os
+import uuid
 
 import mox
 
@@ -32,18 +31,18 @@ from glance.common import exception
 from glance import context
 from glance.db.sqlalchemy import api as db_api
 from glance.openstack.common import timeutils
-from glance.openstack.common import uuidutils
+
+from glance.registry.api import v2 as rserver
 import glance.registry.client.v2.api as rapi
 from glance.registry.client.v2.api import client as rclient
-from glance.registry.api import v2 as rserver
 from glance.tests.unit import base
 from glance.tests import utils as test_utils
 
 
-_gen_uuid = uuidutils.generate_uuid
+_gen_uuid = lambda: str(uuid.uuid4())
 
-UUID1 = _gen_uuid()
-UUID2 = _gen_uuid()
+UUID1 = str(uuid.uuid4())
+UUID2 = str(uuid.uuid4())
 
 #NOTE(bcwaldon): needed to init config_dir cli opt
 config.parse_args(args=[])
@@ -63,7 +62,6 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
     def setUp(self):
         """Establish a clean test environment"""
         super(TestRegistryV2Client, self).setUp()
-        db_api.setup_db_env()
         db_api.get_engine()
         self.context = context.RequestContext(is_admin=True)
         uuid1_time = timeutils.utcnow()
@@ -72,10 +70,11 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
             self.get_extra_fixture(
                 id=UUID1, name='fake image #1', is_public=False,
                 disk_format='ami', container_format='ami', size=13,
+                virtual_size=26, properties={'type': 'kernel'},
                 location="swift://user:passwd@acct/container/obj.tar.0",
-                properties={'type': 'kernel'}, created_at=uuid1_time),
+                created_at=uuid1_time),
             self.get_extra_fixture(id=UUID2, name='fake image #2',
-                                   properties={}, size=19,
+                                   properties={}, size=19, virtual_size=38,
                                    location="file:///tmp/glance-tests/2",
                                    created_at=uuid2_time)]
         self.destroy_fixtures()
@@ -90,7 +89,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
     def test_image_get_index(self):
         """Test correct set of public image returned"""
         images = self.client.image_get_all()
-        self.assertEquals(len(images), 2)
+        self.assertEqual(len(images), 2)
 
     def test_create_image_with_null_min_disk_min_ram(self):
         UUID3 = _gen_uuid()
@@ -206,14 +205,16 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         UUID3 = _gen_uuid()
         extra_fixture = self.get_fixture(id=UUID3, name='asdf',
                                          disk_format='ami',
-                                         container_format='ami', size=100)
+                                         container_format='ami',
+                                         size=100, virtual_size=200)
 
         db_api.image_create(self.context, extra_fixture)
 
         UUID4 = _gen_uuid()
         extra_fixture = self.get_fixture(id=UUID4, name='asdf',
                                          disk_format='iso',
-                                         container_format='bare', size=2)
+                                         container_format='bare',
+                                         size=2, virtual_size=4)
 
         db_api.image_create(self.context, extra_fixture)
 
@@ -297,18 +298,20 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
 
     def test_image_get_index_limit(self):
         """Test correct number of images returned with limit param."""
-        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123',
+        extra_fixture = self.get_fixture(id=_gen_uuid(),
+                                         name='new name! #123',
                                          status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
-        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #125',
+        extra_fixture = self.get_fixture(id=_gen_uuid(),
+                                         name='new name! #125',
                                          status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(limit=2)
-        self.assertEquals(len(images), 2)
+        self.assertEqual(len(images), 2)
 
     def test_image_get_index_marker_limit(self):
         """Test correct set of images returned with marker/limit params."""
@@ -335,33 +338,36 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
 
     def test_image_get_index_limit_None(self):
         """Test correct set of images returned with limit param == None."""
-        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123',
+        extra_fixture = self.get_fixture(id=_gen_uuid(),
+                                         name='new name! #123',
                                          status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
-        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #125',
+        extra_fixture = self.get_fixture(id=_gen_uuid(),
+                                         name='new name! #125',
                                          status='saving')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(limit=None)
-        self.assertEquals(len(images), 4)
+        self.assertEqual(len(images), 4)
 
     def test_image_get_index_by_name(self):
         """
         Test correct set of public, name-filtered image returned. This
         is just a sanity check, we test the details call more in-depth.
         """
-        extra_fixture = self.get_fixture(id=_gen_uuid(), name='new name! #123')
+        extra_fixture = self.get_fixture(id=_gen_uuid(),
+                                         name='new name! #123')
 
         db_api.image_create(self.context, extra_fixture)
 
         images = self.client.image_get_all(filters={'name': 'new name! #123'})
-        self.assertEquals(len(images), 1)
+        self.assertEqual(len(images), 1)
 
         for image in images:
-            self.assertEquals('new name! #123', image['name'])
+            self.assertEqual('new name! #123', image['name'])
 
     def test_image_get_is_public_v2(self):
         """Tests that a detailed call can be filtered by a property"""
@@ -373,25 +379,25 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
 
         filters = {'is_public': 'avalue'}
         images = self.client.image_get_all(filters=filters)
-        self.assertEquals(len(images), 1)
+        self.assertEqual(len(images), 1)
 
         for image in images:
-            self.assertEquals('avalue', image['properties'][0]['value'])
+            self.assertEqual('avalue', image['properties'][0]['value'])
 
     def test_image_get(self):
         """Tests that the detailed info about an image returned"""
         fixture = self.get_fixture(id=UUID1, name='fake image #1',
-                                   is_public=False, size=13,
+                                   is_public=False, size=13, virtual_size=26,
                                    disk_format='ami', container_format='ami')
 
         data = self.client.image_get(image_id=UUID1)
 
         for k, v in fixture.items():
             el = data[k]
-            self.assertEquals(v, data[k],
-                              "Failed v != data[k] where v = %(v)s and "
-                              "k = %(k)s and data[k] = %(el)s" %
-                              dict(v=v, k=k, el=el))
+            self.assertEqual(v, data[k],
+                             "Failed v != data[k] where v = %(v)s and "
+                             "k = %(k)s and data[k] = %(el)s" %
+                             dict(v=v, k=k, el=el))
 
     def test_image_get_non_existing(self):
         """Tests that NotFound is raised when getting a non-existing image"""
@@ -409,11 +415,11 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         data = self.client.image_get(image_id=new_image['id'])
 
         for k, v in fixture.items():
-            self.assertEquals(v, data[k])
+            self.assertEqual(v, data[k])
 
         # Test status was updated properly
         self.assertTrue('status' in data.keys())
-        self.assertEquals('active', data['status'])
+        self.assertEqual('active', data['status'])
 
     def test_image_create_with_properties(self):
         """Tests that we can add image metadata with properties"""
@@ -423,18 +429,18 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         new_image = self.client.image_create(values=fixture)
 
         self.assertIn('properties', new_image)
-        self.assertEquals(new_image['properties'][0]['value'],
-                          fixture['properties']['distro'])
+        self.assertEqual(new_image['properties'][0]['value'],
+                         fixture['properties']['distro'])
 
         del fixture['location']
         del fixture['properties']
 
         for k, v in fixture.items():
-            self.assertEquals(v, new_image[k])
+            self.assertEqual(v, new_image[k])
 
         # Test status was updated properly
         self.assertTrue('status' in new_image.keys())
-        self.assertEquals('active', new_image['status'])
+        self.assertEqual('active', new_image['status'])
 
     def test_image_create_already_exists(self):
         """Tests proper exception is raised if image with ID already exists"""
@@ -457,7 +463,8 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
     def test_image_update(self):
         """Tests that the registry API updates the image"""
         fixture = {'name': 'fake public image #2',
-                   'disk_format': 'vmdk'}
+                   'disk_format': 'vmdk',
+                   'status': 'saving'}
 
         self.assertTrue(self.client.image_update(image_id=UUID2,
                                                  values=fixture))
@@ -466,9 +473,38 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         data = self.client.image_get(image_id=UUID2)
 
         for k, v in fixture.items():
-            self.assertEquals(v, data[k])
+            self.assertEqual(v, data[k])
 
-    def test_image_update_not_existing(self):
+    def test_image_update_conflict(self):
+        """Tests that the registry API updates the image"""
+        next_state = 'saving'
+        fixture = {'name': 'fake public image #2',
+                   'disk_format': 'vmdk',
+                   'status': next_state}
+
+        image = self.client.image_get(image_id=UUID2)
+        current = image['status']
+        self.assertEqual(current, 'active')
+
+        # image is in 'active' state so this should cause a failure.
+        from_state = 'saving'
+
+        self.assertRaises(exception.Conflict, self.client.image_update,
+                          image_id=UUID2, values=fixture,
+                          from_state=from_state)
+
+        try:
+            self.client.image_update(image_id=UUID2, values=fixture,
+                                     from_state=from_state)
+        except exception.Conflict as exc:
+            msg = (_('cannot transition from %(current)s to '
+                     '%(next)s in update (wanted '
+                     'from_state=%(from)s)') %
+                   {'current': current, 'next': next_state,
+                    'from': from_state})
+            self.assertEqual(str(exc), msg)
+
+    def _test_image_update_not_existing(self):
         """Tests non existing image update doesn't work"""
         fixture = self.get_fixture(status='bad status')
 
@@ -486,7 +522,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         image = self.FIXTURES[1]
         deleted_image = self.client.image_destroy(image_id=image['id'])
         self.assertTrue(deleted_image)
-        self.assertEquals(image['id'], deleted_image['id'])
+        self.assertEqual(image['id'], deleted_image['id'])
         self.assertTrue(deleted_image['deleted'])
         self.assertTrue(deleted_image['deleted_at'])
 
@@ -494,7 +530,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         filters = {'deleted': False}
         new_num_images = len(self.client.image_get_all(filters=filters))
 
-        self.assertEquals(new_num_images, orig_num_images - 1)
+        self.assertEqual(new_num_images, orig_num_images - 1)
 
     def test_image_destroy_not_existing(self):
         """Tests cannot delete non-existing image"""
@@ -506,7 +542,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         """Tests getting image members"""
         memb_list = self.client.image_member_find(image_id=UUID2)
         num_members = len(memb_list)
-        self.assertEquals(num_members, 0)
+        self.assertEqual(num_members, 0)
 
     def test_image_get_members_not_existing(self):
         """Tests getting non-existent image members"""
@@ -518,7 +554,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
         """Tests getting member images"""
         memb_list = self.client.image_member_find(member='pattieblack')
         num_members = len(memb_list)
-        self.assertEquals(num_members, 0)
+        self.assertEqual(num_members, 0)
 
     def test_add_update_members(self):
         """Tests updating image members"""
@@ -537,7 +573,7 @@ class TestRegistryV2Client(base.IsolatedUnitTest,
 
         self.client.image_member_delete(memb_id=member['id'])
         memb_list = self.client.image_member_find(member='pattieblack')
-        self.assertEquals(len(memb_list), 0)
+        self.assertEqual(len(memb_list), 0)
 
 
 class TestRegistryV2ClientApi(base.IsolatedUnitTest):
@@ -589,9 +625,9 @@ class TestRegistryV2ClientApi(base.IsolatedUnitTest):
         self.config(auth_region=expected['region'])
         self.stubs.Set(os, 'getenv', lambda x: None)
 
-        self.assertEquals(rapi._CLIENT_CREDS, None)
+        self.assertIsNone(rapi._CLIENT_CREDS)
         rapi.configure_registry_admin_creds()
-        self.assertEquals(rapi._CLIENT_CREDS, expected)
+        self.assertEqual(rapi._CLIENT_CREDS, expected)
 
     def test_configure_registry_admin_creds_with_auth_url(self):
         expected = self._get_fake_config_creds()
@@ -602,6 +638,6 @@ class TestRegistryV2ClientApi(base.IsolatedUnitTest):
         self.config(auth_strategy='test_strategy')
         self.config(auth_region=expected['region'])
 
-        self.assertEquals(rapi._CLIENT_CREDS, None)
+        self.assertIsNone(rapi._CLIENT_CREDS)
         rapi.configure_registry_admin_creds()
-        self.assertEquals(rapi._CLIENT_CREDS, expected)
+        self.assertEqual(rapi._CLIENT_CREDS, expected)
