@@ -32,7 +32,7 @@ class TestSchemasController(test_utils.BaseTestCase):
                         'disk_format', 'updated_at', 'visibility', 'self',
                         'file', 'container_format', 'schema', 'id', 'size',
                         'direct_url', 'min_ram', 'min_disk', 'protected',
-                        'locations'])
+                        'locations', 'owner', 'virtual_size'])
         self.assertEqual(set(output['properties'].keys()), expected)
 
     def test_images(self):
